@@ -32,8 +32,12 @@ from ..widgets.gtk_utils import show_error, ask_question, show_dialog_with_icon
 from .page_handler import PageHandler
 from .policy_rules import AbstractRuleWrapper, AbstractVerbDescription
 from .policy_manager import PolicyManager
-from .rule_list_widgets import RuleListBoxRow, FilteredListBoxRow, \
-    ErrorRuleRow, LIMITED_CATEGORIES
+from .rule_list_widgets import (
+    RuleListBoxRow,
+    FilteredListBoxRow,
+    ErrorRuleRow,
+    LIMITED_CATEGORIES,
+)
 from .conflict_handler import ConflictFileHandler
 
 import gi
@@ -42,26 +46,31 @@ import qubesadmin
 import qubesadmin.vm
 from ..widgets.utils import compare_rule_lists
 
-gi.require_version('Gtk', '3.0')
+gi.require_version("Gtk", "3.0")
 from gi.repository import Gtk
 
 import gettext
+
 t = gettext.translation("desktop-linux-manager", fallback=True)
 _ = t.gettext
 
+
 class PolicyHandler(PageHandler):
     """Handler for a single page with Policy settings."""
-    def __init__(self,
-                 qapp: qubesadmin.Qubes,
-                 gtk_builder: Gtk.Builder,
-                 prefix: str,
-                 policy_manager: PolicyManager,
-                 default_policy: str,
-                 service_name: str,
-                 policy_file_name: str,
-                 verb_description: AbstractVerbDescription,
-                 rule_class: Type[AbstractRuleWrapper],
-                 include_admin_vm: bool = False):
+
+    def __init__(
+        self,
+        qapp: qubesadmin.Qubes,
+        gtk_builder: Gtk.Builder,
+        prefix: str,
+        policy_manager: PolicyManager,
+        default_policy: str,
+        service_name: str,
+        policy_file_name: str,
+        verb_description: AbstractVerbDescription,
+        rule_class: Type[AbstractRuleWrapper],
+        include_admin_vm: bool = False,
+    ):
         """
         :param qapp: Qubes object
         :param gtk_builder: gtk_builder; to avoid inelegant design, this should
@@ -89,30 +98,35 @@ class PolicyHandler(PageHandler):
         self.include_adminvm = include_admin_vm
 
         # main widgets
-        self.main_list_box: Gtk.ListBox = \
-            gtk_builder.get_object(f'{prefix}_main_list')
-        self.exception_list_box: Gtk.ListBox = \
-            gtk_builder.get_object(f'{prefix}_exception_list')
+        self.custom_settings_box: Gtk.Box = gtk_builder.get_object(
+            f"{prefix}_custom_box"
+        )
+
+        self.main_list_box: Gtk.ListBox = gtk_builder.get_object(f"{prefix}_main_list")
+        self.exception_list_box: Gtk.ListBox = gtk_builder.get_object(
+            f"{prefix}_exception_list"
+        )
 
         # add new rule button
-        self.add_button: Gtk.Button = \
-            gtk_builder.get_object(f'{prefix}_add_rule_button')
+        self.add_button: Gtk.Button = gtk_builder.get_object(
+            f"{prefix}_add_rule_button"
+        )
 
         # enable/disable custom policy
         self.enable_radio: Gtk.RadioButton = gtk_builder.get_object(
-            f'{prefix}_enable_radio')
+            f"{prefix}_enable_radio"
+        )
         self.disable_radio: Gtk.RadioButton = gtk_builder.get_object(
-            f'{prefix}_disable_radio')
+            f"{prefix}_disable_radio"
+        )
 
         # connect events
         self.add_button.connect("clicked", self.add_new_rule)
 
-        self.exception_list_box.connect('row-activated', self._rule_clicked)
-        self.main_list_box.connect('row-activated', self._rule_clicked)
-        self.exception_list_box.connect('rules-changed',
-                                        self._populate_raw_rules)
-        self.main_list_box.connect('rules-changed',
-                                   self._populate_raw_rules)
+        self.exception_list_box.connect("row-activated", self._rule_clicked)
+        self.main_list_box.connect("row-activated", self._rule_clicked)
+        self.exception_list_box.connect("rules-changed", self._populate_raw_rules)
+        self.main_list_box.connect("rules-changed", self._populate_raw_rules)
 
         self.enable_radio.connect("toggled", self._custom_toggled)
         self.disable_radio.connect("toggled", self._custom_toggled)
@@ -121,26 +135,30 @@ class PolicyHandler(PageHandler):
         self.main_list_box.set_sort_func(self.rule_sorting_function)
 
         self.conflict_handler = ConflictFileHandler(
-            gtk_builder=gtk_builder, prefix=prefix,
+            gtk_builder=gtk_builder,
+            prefix=prefix,
             service_names=[self.service_name],
             own_file_name=self.policy_file_name,
-            policy_manager=self.policy_manager)
+            policy_manager=self.policy_manager,
+        )
 
         self.error_handler = ErrorHandler(gtk_builder, prefix)
 
         self.raw_handler = RawPolicyTextHandler(
-            gtk_builder=gtk_builder, prefix=prefix,
+            gtk_builder=gtk_builder,
+            prefix=prefix,
             policy_manager=self.policy_manager,
             error_handler=self.error_handler,
             callback_on_save_raw=self.populate_rule_lists,
-            callback_on_open_raw=self.close_all_edits)
+            callback_on_open_raw=self.close_all_edits,
+        )
 
         # fill data
         self.initial_rules: List[Rule] = []
         self.current_token: Optional[str] = None
         self.initialize_data()
 
-        self.main_list_box.connect('map', self.on_switch)
+        self.main_list_box.connect("map", self.on_switch)
 
     def _populate_raw_rules(self, *_args):
         self.raw_handler.fill_raw(self.current_rules)
@@ -149,12 +167,19 @@ class PolicyHandler(PageHandler):
         """Add a new rule."""
         self.close_all_edits()
         deny_all_rule = self.policy_manager.new_rule(
-            service=self.service_name, source='@anyvm',
-            target='@anyvm', action='deny')
-        new_row = RuleListBoxRow(self,
-            self.rule_class(deny_all_rule), self.qapp, self.verb_description,
-                                 is_new_row=True,
-                                 enable_adminvm=self.include_adminvm)
+            service=self.service_name,
+            source="@anyvm",
+            target="@anyvm",
+            action="deny",
+        )
+        new_row = RuleListBoxRow(
+            self,
+            self.rule_class(deny_all_rule),
+            self.qapp,
+            self.verb_description,
+            is_new_row=True,
+            enable_adminvm=self.include_adminvm,
+        )
         self.exception_list_box.add(new_row)
         new_row.activate()
 
@@ -165,21 +190,21 @@ class PolicyHandler(PageHandler):
         """
         if self.disable_radio.get_active():
             return self.policy_manager.text_to_rules(self.default_policy)
-        return [row.rule.raw_rule for row in self.current_rows if
-                not row.is_new_row]
+        return [row.rule.raw_rule for row in self.current_rows if not row.is_new_row]
 
     @property
     def current_rows(self) -> List[RuleListBoxRow]:
         """
         Get the current list of all RuleListBoxRows
         """
-        return self.exception_list_box.get_children() + \
-               self.main_list_box.get_children()
+        return (
+            self.exception_list_box.get_children() + self.main_list_box.get_children()
+        )
 
     def initialize_data(self):
-        rules, self.current_token = \
-            self.policy_manager.get_rules_from_filename(
-                self.policy_file_name, self.default_policy)
+        rules, self.current_token = self.policy_manager.get_rules_from_filename(
+            self.policy_file_name, self.default_policy
+        )
 
         # fill data
         self.populate_rule_lists(rules)
@@ -202,38 +227,59 @@ class PolicyHandler(PageHandler):
                 if wrapped_rule.is_rule_fundamental():
                     self.main_list_box.add(
                         RuleListBoxRow(
-                            self, wrapped_rule, self.qapp,
-                            self.verb_description, enable_delete=False,
+                            self,
+                            wrapped_rule,
+                            self.qapp,
+                            self.verb_description,
+                            enable_delete=False,
                             enable_vm_edit=False,
-                            enable_adminvm=self.include_adminvm))
+                            enable_adminvm=self.include_adminvm,
+                        )
+                    )
                     continue
-                fundamental = self.include_adminvm and \
-                              rule.source == '@adminvm' and \
-                              rule.target == '@anyvm'
-                self.exception_list_box.add(RuleListBoxRow(self,
-                    rule=wrapped_rule, qapp=self.qapp,
-                    verb_description=self.verb_description,
-                    enable_delete=not fundamental,
-                    enable_vm_edit=not fundamental,
-                    enable_adminvm=self.include_adminvm))
+                fundamental = (
+                    self.include_adminvm
+                    and rule.source == "@adminvm"
+                    and rule.target == "@anyvm"
+                )
+                self.exception_list_box.add(
+                    RuleListBoxRow(
+                        self,
+                        rule=wrapped_rule,
+                        qapp=self.qapp,
+                        verb_description=self.verb_description,
+                        enable_delete=not fundamental,
+                        enable_vm_edit=not fundamental,
+                        enable_adminvm=self.include_adminvm,
+                    )
+                )
             except Exception:  # pylint: disable=broad-except
                 self.error_handler.add_error(rule)
 
         if not self.main_list_box.get_children():
             deny_all_rule = self.policy_manager.new_rule(
-                service=self.service_name, source='@anyvm',
-                target='@anyvm', action='deny')
+                service=self.service_name,
+                source="@anyvm",
+                target="@anyvm",
+                action="deny",
+            )
             self.main_list_box.add(
-                RuleListBoxRow(self,
-                    self.rule_class(deny_all_rule), self.qapp,
+                RuleListBoxRow(
+                    self,
+                    self.rule_class(deny_all_rule),
+                    self.qapp,
                     self.verb_description,
-                    enable_delete=False, enable_vm_edit=False,
-                    enable_adminvm=self.include_adminvm))
+                    enable_delete=False,
+                    enable_vm_edit=False,
+                    enable_adminvm=self.include_adminvm,
+                )
+            )
 
         self.check_custom_rules(rules)
 
     def set_custom_editable(self, state: bool):
-        """If true, set widgets to accept editing custom rules."""
+        """If true, set widgets to accept editing custom rules and show them."""
+        self.custom_settings_box.set_visible(state)
         self.add_button.set_sensitive(state)
         self.main_list_box.set_sensitive(state)
         self.exception_list_box.set_sensitive(state)
@@ -245,12 +291,12 @@ class PolicyHandler(PageHandler):
         # otherwise compare lexically
         if token_1 == token_2:
             return 0
-        if token_1 == '@anyvm':
+        if token_1 == "@anyvm":
             return 1
-        if token_2 == '@anyvm':
+        if token_2 == "@anyvm":
             return -1
-        is_token_1_keyword = token_1.startswith('@')
-        is_token_2_keyword = token_2.startswith('@')
+        is_token_1_keyword = token_1.startswith("@")
+        is_token_2_keyword = token_2.startswith("@")
         if is_token_1_keyword == is_token_2_keyword:
             if token_1 < token_2:
                 return -1
@@ -259,8 +305,7 @@ class PolicyHandler(PageHandler):
             return 1
         return -1
 
-    def rule_sorting_function(self,
-                              row_1: RuleListBoxRow, row_2: RuleListBoxRow):
+    def rule_sorting_function(self, row_1: RuleListBoxRow, row_2: RuleListBoxRow):
         """Sorting function for exceptions."""
         source_cmp = self.cmp_token(row_1.rule.source, row_2.rule.source)
         if source_cmp != 0:
@@ -272,8 +317,7 @@ class PolicyHandler(PageHandler):
         Check if the provided set of rules is the same as the default set,
         set radio buttons accordingly.
         """
-        if self.policy_manager.compare_rules_to_text(rules,
-                                                     self.default_policy):
+        if self.policy_manager.compare_rules_to_text(rules, self.default_policy):
             self.disable_radio.set_active(True)
         else:
             self.enable_radio.set_active(True)
@@ -292,10 +336,13 @@ class PolicyHandler(PageHandler):
         row.set_edit_mode(True)
 
     @staticmethod
-    def verify_rule_against_rows(other_rows: List[RuleListBoxRow],
-                                 row: RuleListBoxRow,
-                                 new_source: str, new_target: str,
-                                 new_action: str) -> Optional[str]:
+    def verify_rule_against_rows(
+        other_rows: List[RuleListBoxRow],
+        row: RuleListBoxRow,
+        new_source: str,
+        new_target: str,
+        new_action: str,
+    ) -> Optional[str]:
         """
         Verify correctness of a rule with new_source, new_target and new_action
         if it was to be associated with provided row. Return None if rule would
@@ -304,21 +351,25 @@ class PolicyHandler(PageHandler):
         for other_row in other_rows:
             if other_row == row:
                 continue
-            if other_row.rule.is_rule_conflicting(new_source, new_target,
-                                                  new_action):
+            if other_row.rule.is_rule_conflicting(new_source, new_target, new_action):
                 return str(other_row)
         return None
 
-    def verify_new_rule(self, row: RuleListBoxRow,
-                        new_source: str, new_target: str,
-                        new_action: str) -> Optional[str]:
+    def verify_new_rule(
+        self,
+        row: RuleListBoxRow,
+        new_source: str,
+        new_target: str,
+        new_action: str,
+    ) -> Optional[str]:
         """
         Verify correctness of a rule with new_source, new_target and new_action
         if it was to be associated with provided row. Return None if rule would
         be correct, and string description of error otherwise.
         """
-        return self.verify_rule_against_rows(self.current_rows, row,
-                                      new_source, new_target, new_action)
+        return self.verify_rule_against_rows(
+            self.current_rows, row, new_source, new_target, new_action
+        )
 
     @staticmethod
     def close_rows_in_list(row_list: List[RuleListBoxRow]):
@@ -329,14 +380,20 @@ class PolicyHandler(PageHandler):
                     row.set_edit_mode(False)
                     continue
                 response = show_dialog_with_icon(
-                    parent=row.get_toplevel(), title=_("Unsaved changes"),
-                    text=_("A rule is currently being edited. \n"
-                         "Do you want to save changes to the following"
-                         "rule?\n") + str(row),
+                    parent=row.get_toplevel(),
+                    title=_("Unsaved changes"),
+                    text=_(
+                        "A rule is currently being edited. \n"
+                        "Do you want to save changes to the following"
+                        "rule?\n"
+                    )
+                    + str(row),
                     buttons={
                         _("_Save changes"): Gtk.ResponseType.YES,
                         _("_Discard changes"): Gtk.ResponseType.NO,
-                    }, icon_name="qubes-ask")
+                    },
+                    icon_name="qubes-ask",
+                )
 
                 if response == Gtk.ResponseType.YES:
                     if not row.validate_and_save():
@@ -357,10 +414,10 @@ class PolicyHandler(PageHandler):
     def save(self):
         """Save current rules, whatever they are - custom or default."""
         rules = self.current_rules
-        self.policy_manager.save_rules(self.policy_file_name,
-                                       rules, self.current_token)
+        self.policy_manager.save_rules(self.policy_file_name, rules, self.current_token)
         _r, self.current_token = self.policy_manager.get_rules_from_filename(
-            self.policy_file_name, self.default_policy)
+            self.policy_file_name, self.default_policy
+        )
 
         self.initial_rules = deepcopy(rules)
 
@@ -378,25 +435,32 @@ class PolicyHandler(PageHandler):
 
     def on_switch(self, *_args):
         if self.error_handler.get_errors():
-            rule_text = "\n".join(str(rule) for rule in
-                                  self.error_handler.get_errors())
+            rule_text = "\n".join(str(rule) for rule in self.error_handler.get_errors())
             show_error(
                 parent=self.main_list_box.get_toplevel(),
                 title=_("Unknown rule found in police file"),
-                text=_("The following rules could not be parsed:\n") +
-                     rule_text + _("\nThis has probably happened due to "
-                                   "manual editing of the policy file. The "
-                                   "rule will be discarded.")
+                text=_("The following rules could not be parsed:\n")
+                + rule_text
+                + _(
+                    "\nThis has probably happened due to "
+                    "manual editing of the policy file. The "
+                    "rule will be discarded."
+                ),
             )
 
 
 class RawPolicyTextHandler:
     """Class that handles raw text widgets"""
-    def __init__(self, gtk_builder: Gtk.Builder, prefix: str,
-                 policy_manager: PolicyManager,
-                 error_handler: 'ErrorHandler',
-                 callback_on_save_raw: Optional[Callable[[List[Rule]], None]],
-                 callback_on_open_raw: Optional[Callable]):
+
+    def __init__(
+        self,
+        gtk_builder: Gtk.Builder,
+        prefix: str,
+        policy_manager: PolicyManager,
+        error_handler: "ErrorHandler",
+        callback_on_save_raw: Optional[Callable[[List[Rule]], None]],
+        callback_on_open_raw: Optional[Callable],
+    ):
         """
         :param gtk_builder: Gtk.Builder
         :param prefix: prefix for widgets
@@ -410,18 +474,16 @@ class RawPolicyTextHandler:
         self.error_handler = error_handler
         self.callback_on_save_raw = callback_on_save_raw
 
-        self.raw_event_button: Gtk.Button = \
-            gtk_builder.get_object(f'{prefix}_raw_event')
-        self.raw_box: Gtk.Box = \
-            gtk_builder.get_object(f'{prefix}_raw_box')
-        self.raw_expander_icon: Gtk.Image = \
-            gtk_builder.get_object(f'{prefix}_raw_expander')
-        self.raw_text: Gtk.TextView = gtk_builder.get_object(
-            f'{prefix}_raw_text')
-        self.raw_save: Gtk.Button = gtk_builder.get_object(
-            f'{prefix}_raw_save')
-        self.raw_cancel: Gtk.Button = gtk_builder.get_object(
-            f'{prefix}_raw_cancel')
+        self.raw_event_button: Gtk.Button = gtk_builder.get_object(
+            f"{prefix}_raw_event"
+        )
+        self.raw_box: Gtk.Box = gtk_builder.get_object(f"{prefix}_raw_box")
+        self.raw_expander_icon: Gtk.Image = gtk_builder.get_object(
+            f"{prefix}_raw_expander"
+        )
+        self.raw_text: Gtk.TextView = gtk_builder.get_object(f"{prefix}_raw_text")
+        self.raw_save: Gtk.Button = gtk_builder.get_object(f"{prefix}_raw_save")
+        self.raw_cancel: Gtk.Button = gtk_builder.get_object(f"{prefix}_raw_cancel")
         self.text_buffer: Gtk.TextBuffer = self.raw_text.get_buffer()
 
         self.raw_save.connect("clicked", self._save_raw)
@@ -431,7 +493,7 @@ class RawPolicyTextHandler:
             event_button=self.raw_event_button,
             data_container=self.raw_box,
             icon=self.raw_expander_icon,
-            event_callback=callback_on_open_raw
+            event_callback=callback_on_open_raw,
         )
 
         self.last_known_rules: List[Rule] = []
@@ -441,23 +503,28 @@ class RawPolicyTextHandler:
             rules: List[Rule] = self.policy_manager.text_to_rules(
                 self.text_buffer.get_text(
                     self.text_buffer.get_start_iter(),
-                    self.text_buffer.get_end_iter(), False))
+                    self.text_buffer.get_end_iter(),
+                    False,
+                )
+            )
             if self.callback_on_save_raw:
                 self.callback_on_save_raw(rules)
 
             if self.error_handler.get_errors():
-                rule_text = "\n".join(str(rule) for rule in
-                                  self.error_handler.get_errors())
+                rule_text = "\n".join(
+                    str(rule) for rule in self.error_handler.get_errors()
+                )
                 raise PolicySyntaxError(None, None, rule_text)
 
             self.expander_handler.set_state(False)
         except PolicySyntaxError as ex:
-            error_message = str(ex).split(':', 3)[2]
+            error_message = str(ex).split(":", 3)[2]
             show_error(
                 parent=self.raw_box.get_toplevel(),
                 title=_("Error parsing rules"),
-                text=_("The following rules could not be parsed:\n") +
-                     error_message + "\n"
+                text=_("The following rules could not be parsed:\n")
+                + error_message
+                + "\n",
             )
 
     def _cancel_raw(self, _widget):
@@ -481,18 +548,21 @@ class VMSubsetPolicyHandler(PolicyHandler):
     of VMs, that is, SplitGPG. Currently makes SplitGPG assumptions, such
     as networked qube is dangerous.
     """
-    def __init__(self,
-                 qapp: qubesadmin.Qubes,
-                 gtk_builder: Gtk.Builder,
-                 prefix: str,
-                 policy_manager: PolicyManager,
-                 default_policy: str,
-                 service_name: str,
-                 policy_file_name: str,
-                 main_verb_description: AbstractVerbDescription,
-                 main_rule_class: Type[AbstractRuleWrapper],
-                 exception_verb_description: AbstractVerbDescription,
-                 exception_rule_class: Type[AbstractRuleWrapper]):
+
+    def __init__(
+        self,
+        qapp: qubesadmin.Qubes,
+        gtk_builder: Gtk.Builder,
+        prefix: str,
+        policy_manager: PolicyManager,
+        default_policy: str,
+        service_name: str,
+        policy_file_name: str,
+        main_verb_description: AbstractVerbDescription,
+        main_rule_class: Type[AbstractRuleWrapper],
+        exception_verb_description: AbstractVerbDescription,
+        exception_rule_class: Type[AbstractRuleWrapper],
+    ):
         """
         :param qapp: Qubes object
         :param gtk_builder: gtk_builder; to avoid inelegant design, this should
@@ -520,52 +590,70 @@ class VMSubsetPolicyHandler(PolicyHandler):
 
         # main widgets
         self.add_select_box: Gtk.Box = gtk_builder.get_object(
-            f'{prefix}_add_select_box')
+            f"{prefix}_add_select_box"
+        )
         self.add_select_button: Gtk.Button = gtk_builder.get_object(
-            f'{prefix}_add_select_button')
+            f"{prefix}_add_select_button"
+        )
         self.add_select_confirm: Gtk.Button = gtk_builder.get_object(
-            f'{prefix}_add_select_confirm')
+            f"{prefix}_add_select_confirm"
+        )
         self.add_select_cancel: Gtk.Button = gtk_builder.get_object(
-            f'{prefix}_add_select_cancel')
+            f"{prefix}_add_select_cancel"
+        )
         self.select_qube_combo: Gtk.ComboBox = gtk_builder.get_object(
-            f'{prefix}_select_qube_combo')
+            f"{prefix}_select_qube_combo"
+        )
 
         super().__init__(
-            qapp, gtk_builder, prefix, policy_manager, default_policy,
-            service_name, policy_file_name, exception_verb_description,
-            exception_rule_class)
+            qapp,
+            gtk_builder,
+            prefix,
+            policy_manager,
+            default_policy,
+            service_name,
+            policy_file_name,
+            exception_verb_description,
+            exception_rule_class,
+        )
 
         # populate combo
         self.select_qube_model = VMListModeler(
-            combobox=self.select_qube_combo,
-            qapp=self.qapp)
+            combobox=self.select_qube_combo, qapp=self.qapp
+        )
 
         # connect events
-        self.add_select_button.connect('clicked', self._add_select_qube)
-        self.add_select_confirm.connect('clicked', self._add_select_confirm)
-        self.add_select_cancel.connect('clicked', self._add_select_cancel)
+        self.add_select_button.connect("clicked", self._add_select_qube)
+        self.add_select_confirm.connect("clicked", self._add_select_confirm)
+        self.add_select_cancel.connect("clicked", self._add_select_cancel)
 
-        self.main_list_box.connect('rules-changed', self._select_qubes_changed)
+        self.main_list_box.connect("rules-changed", self._select_qubes_changed)
 
     def _select_qubes_changed(self, *_args):
         self.close_all_edits()
-        self.select_qubes = {row.rule.target for row in
-                        self.main_list_box.get_children()}
+        self.select_qubes = {
+            row.rule.target for row in self.main_list_box.get_children()
+        }
         self.populate_rule_lists(self.current_rules, drop_obsolete=True)
 
     def _add_main_rule(self, rule):
-        self.main_list_box.add(RuleListBoxRow(
-            parent_handler=self,
-            rule=self.main_rule_class(rule),
-            qapp=self.qapp,
-            verb_description=self.main_verb_description,
-            enable_delete=True,
-            enable_vm_edit=False, initial_verb="",
-            custom_deletion_warning=_("Are you sure you want to delete this "
-                                      "rule? All related exceptions will also "
-                                      "be deleted."),
-            enable_adminvm=self.include_adminvm
-        ))
+        self.main_list_box.add(
+            RuleListBoxRow(
+                parent_handler=self,
+                rule=self.main_rule_class(rule),
+                qapp=self.qapp,
+                verb_description=self.main_verb_description,
+                enable_delete=True,
+                enable_vm_edit=False,
+                initial_verb="",
+                custom_deletion_warning=_(
+                    "Are you sure you want to delete this "
+                    "rule? All related exceptions will also "
+                    "be deleted."
+                ),
+                enable_adminvm=self.include_adminvm,
+            )
+        )
 
     def _add_exception_rule(self, rule):
         row = FilteredListBoxRow(
@@ -575,7 +663,7 @@ class VMSubsetPolicyHandler(PolicyHandler):
             initial_verb=_("will"),
             verb_description=self.exception_verb_description,
             filter_target=lambda x: str(x) in self.select_qubes,
-            source_categories=LIMITED_CATEGORIES
+            source_categories=LIMITED_CATEGORIES,
         )
         self.exception_list_box.add(row)
         return row
@@ -586,16 +674,18 @@ class VMSubsetPolicyHandler(PolicyHandler):
         # there exists a rule with @default and that target as target
         # or default target
         for other_rule in rules:
-            if other_rule.source == rule.source and \
-                    other_rule.target == '@default' and (
+            if (
+                other_rule.source == rule.source
+                and other_rule.target == "@default"
+                and (
                     getattr(other_rule.action, "target", None) == rule.target
-                    or getattr(other_rule.action, "default_target", None) ==
-                    rule.target):
+                    or getattr(other_rule.action, "default_target", None) == rule.target
+                )
+            ):
                 return True
         return False
 
-    def populate_rule_lists(self, rules: List[Rule],
-                            drop_obsolete: bool = False):
+    def populate_rule_lists(self, rules: List[Rule], drop_obsolete: bool = False):
         """
         Populate the rule lists.
         :param rules: List of Rule objects
@@ -603,8 +693,9 @@ class VMSubsetPolicyHandler(PolicyHandler):
         in key qube list be silently discarded?
         :return:
         """
-        for child in self.main_list_box.get_children() + \
-                     self.exception_list_box.get_children():
+        for child in (
+            self.main_list_box.get_children() + self.exception_list_box.get_children()
+        ):
             child.get_parent().remove(child)
         # rules with source = '@anyvm' go to main list and their
         # qubes are key qubes
@@ -614,32 +705,33 @@ class VMSubsetPolicyHandler(PolicyHandler):
 
         for rule in reversed(rules):
             try:
-                if rule.source == '@anyvm':
-                    if rule.target.type == 'keyword':
+                if rule.source == "@anyvm":
+                    if rule.target.type == "keyword":
                         # we do not support this
                         self.error_handler.add_error(rule)
                         continue
                     self._add_main_rule(rule)
-            except Exception: # pylint: disable=broad-except
+            except Exception:  # pylint: disable=broad-except
                 self.error_handler.add_error(rule)
                 continue
 
-        self.select_qubes = {row.rule.target for row in
-                        self.main_list_box.get_children()}
+        self.select_qubes = {
+            row.rule.target for row in self.main_list_box.get_children()
+        }
 
         for rule in reversed(rules):
             try:
-                if rule.target != '@default':
+                if rule.target != "@default":
                     if self._has_partial_duplicate(rule, rules):
                         continue
-                if rule.source != '@anyvm':
+                if rule.source != "@anyvm":
                     wrapped_exception_rule = self.exception_rule_class(rule)
                     if wrapped_exception_rule.target not in self.select_qubes:
                         if not drop_obsolete:
                             self.error_handler.add_error(rule)
                         continue
                     self._add_exception_rule(rule)
-            except Exception: # pylint: disable=broad-except
+            except Exception:  # pylint: disable=broad-except
                 self.error_handler.add_error(rule)
                 continue
         self.add_button.set_sensitive(bool(self.main_list_box.get_children()))
@@ -657,27 +749,38 @@ class VMSubsetPolicyHandler(PolicyHandler):
     def _add_select_confirm(self, *_args):
         new_qube = self.select_qube_model.get_selected()
         if not new_qube or not isinstance(new_qube, qubesadmin.vm.QubesVM):
-            show_error(self.main_list_box, _('Invalid selection'),
-                       _('Invalid object was selected. {new_qube} is not a '
-                         'valid Qubes qube.').format(new_qube=new_qube))
+            show_error(
+                self.main_list_box,
+                _("Invalid selection"),
+                _(
+                    "Invalid object was selected. {new_qube} is not a "
+                    "valid Qubes qube."
+                ).format(new_qube=new_qube),
+            )
             return
         if new_qube.is_networked():
             response = ask_question(
                 self.main_list_box,
                 _("Add new key qube"),
-                _("Are you sure you want to add {new_qube} as a key qube? It "
-                  "has network access, which may lead to decreased "
-                  "security.").format(new_qube=new_qube))
+                _(
+                    "Are you sure you want to add {new_qube} as a key qube? It "
+                    "has network access, which may lead to decreased "
+                    "security."
+                ).format(new_qube=new_qube),
+            )
             if response == Gtk.ResponseType.NO:
                 self._add_select_cancel()
                 return
         new_qube = str(self.select_qube_model.get_selected())
         new_rule = self.policy_manager.new_rule(
-            service=self.service_name, source='@anyvm',
-            target=new_qube, action='ask')
+            service=self.service_name,
+            source="@anyvm",
+            target=new_qube,
+            action="ask",
+        )
         self._add_main_rule(new_rule)
         self.add_select_box.set_visible(False)
-        self.main_list_box.emit('rules-changed', None)
+        self.main_list_box.emit("rules-changed", None)
 
     def _add_select_cancel(self, *_args):
         self.add_select_box.set_visible(False)
@@ -687,8 +790,11 @@ class VMSubsetPolicyHandler(PolicyHandler):
         self.close_all_edits()
         for qube in self.select_qubes:
             rule = self.policy_manager.new_rule(
-                service=self.service_name, source=str(qube),
-                target=str(qube), action='deny')
+                service=self.service_name,
+                source=str(qube),
+                target=str(qube),
+                action="deny",
+            )
             new_row = self._add_exception_rule(rule)
             new_row.is_new_row = True
             new_row.activate()
@@ -716,7 +822,7 @@ class VMSubsetPolicyHandler(PolicyHandler):
                 continue
             rules.append(new_rule)
 
-            if new_rule.target == '@default':
+            if new_rule.target == "@default":
                 if getattr(new_rule.action, "default_target", None):
                     new_target = new_rule.action.default_target
                 elif getattr(new_rule.action, "target", None):
@@ -724,20 +830,22 @@ class VMSubsetPolicyHandler(PolicyHandler):
                 else:
                     continue
                 another_rule = self.policy_manager.new_rule(
-                    service=self.service_name, source=new_rule.source,
+                    service=self.service_name,
+                    source=new_rule.source,
                     target=new_target,
-                    action=type(new_rule.action).__name__.lower())
+                    action=type(new_rule.action).__name__.lower(),
+                )
                 if str(another_rule) in [str(rule) for rule in rules]:
                     # do not save duplicates
                     continue
                 rules.append(another_rule)
-        rules.extend([row.rule.raw_rule for row in
-                      self.main_list_box.get_children()])
+        rules.extend([row.rule.raw_rule for row in self.main_list_box.get_children()])
         return rules
 
 
 class ErrorHandler:
     """A helper class to manage boxes with error lists."""
+
     def __init__(self, gtk_builder, prefix: str):
         """
         :param gtk_builder: Gtk.Builder
@@ -745,9 +853,8 @@ class ErrorHandler:
         - prefix_error_box that contains all error widgets
         - prefix_error_list, a ListBox that contains erroneous rules
         """
-        self.error_box: Gtk.Box = gtk_builder.get_object(f'{prefix}_error_box')
-        self.error_list: Gtk.ListBox = gtk_builder.get_object(
-            f'{prefix}_error_list')
+        self.error_box: Gtk.Box = gtk_builder.get_object(f"{prefix}_error_box")
+        self.error_list: Gtk.ListBox = gtk_builder.get_object(f"{prefix}_error_list")
 
         self._errors: List[Rule] = []
 
