@@ -21,17 +21,28 @@
 import abc
 
 from typing import Dict, Optional
-from qrexec.policy.parser import Rule, Allow, Ask, Source, Target, Action, \
-    DispVM, DispVMTemplate
+from qrexec.policy.parser import (
+    Rule,
+    Allow,
+    Ask,
+    Source,
+    Target,
+    Action,
+    DispVM,
+    DispVMTemplate,
+)
 
 import gettext
+
 t = gettext.translation("desktop-linux-manager", fallback=True)
 _ = t.gettext
 
+
 class AbstractRuleWrapper(abc.ABC):
     """Wrapper for Rule objects.
     ACTION_CHOICES provides human-understandable names for choosing
     action value in dropdowns."""
+
     ACTION_CHOICES: Dict[str, str] = {}
 
     def __init__(self, rule: Rule):
@@ -83,24 +94,25 @@ class AbstractRuleWrapper(abc.ABC):
         Return True if the rule should be placed in the main list, False if it's
         an exception.
         """
-        return self.source == '@anyvm' and self.target == '@anyvm'
+        return self.source == "@anyvm" and self.target == "@anyvm"
 
-    def is_rule_conflicting(self, other_source: str, other_target: str,
-                            other_action: str) -> bool:
+    def is_rule_conflicting(
+        self, other_source: str, other_target: str, other_action: str
+    ) -> bool:
         # pylint: disable=unused-argument
         """
         Return True if rule with other_source and other_target would conflict
          with self.
         """
-        return self.source == other_source and \
-               self.target == other_target
+        return self.source == other_source and self.target == other_target
 
     @staticmethod
-    def get_rule_errors(source: str, target: str, action: str) -> \
-            Optional[str]: # pylint: disable=unused-argument
+    # pylint: disable=unused-argument
+    def get_rule_errors(source: str, target: str, action: str) -> Optional[str]:
         """Return None if rule is valid and str describing error if not."""
         return None
 
+
 class RuleSimple(AbstractRuleWrapper):
     """
     Simple Rule wrapper, where:
@@ -109,20 +121,20 @@ class RuleSimple(AbstractRuleWrapper):
     action = just action, without params.
     Returns and accepts strings as target/source/action.
     """
-    ACTION_CHOICES = {
-        "ask": _("ask"),
-        "allow": _("always"),
-        "deny": _("never")
-    }
+
+    ACTION_CHOICES = {"ask": _("ask"), "allow": _("always"), "deny": _("never")}
+
     def __init__(self, rule: Rule):
         """
         :param rule: Rule object
         """
         super().__init__(rule)
 
-        if str(rule.action) not in ['ask', 'deny', 'allow'] \
-                or rule.argument is not None:
-            raise ValueError(_('Unrecognized action: ') + str(rule.action))
+        if (
+            str(rule.action) not in ["ask", "deny", "allow"]
+            or rule.argument is not None
+        ):
+            raise ValueError(_("Unrecognized action: ") + str(rule.action))
 
     @property
     def target(self):
@@ -158,36 +170,34 @@ class RuleSimple(AbstractRuleWrapper):
     def raw_rule(self):
         return self._rule
 
+
 class RuleSimpleAskIsAllow(RuleSimple):
     """Simple rule where there is no Allow and Ask is pretending to be Allow.
     Used chiefly by Clipboard rules."""
-    ACTION_CHOICES = {
-        "ask": _("always"),
-        "deny": _("never")
-    }
+
+    ACTION_CHOICES = {"ask": _("always"), "deny": _("never")}
+
     def __init__(self, rule: Rule):
         """
         :param rule: Rule object
         """
         super().__init__(rule)
 
-        if str(rule.action) not in ['ask', 'deny'] or rule.argument is not None:
-            raise ValueError(_('Unrecognized action: ') + str(rule.action))
+        if str(rule.action) not in ["ask", "deny"] or rule.argument is not None:
+            raise ValueError(_("Unrecognized action: ") + str(rule.action))
 
     @staticmethod
-    def get_rule_errors(source: str, target: str, action: str) -> \
-            Optional[str]:
+    def get_rule_errors(source: str, target: str, action: str) -> Optional[str]:
         # action must be a simple ask/allow/deny
-        if action not in ['ask', 'deny']:
-            return _('Unrecognized action: ') + action
+        if action not in ["ask", "deny"]:
+            return _("Unrecognized action: ") + action
         return None
 
+
 class RuleSimpleNoAllow(RuleSimple):
     """Simple rule that has no Allow option"""
-    ACTION_CHOICES = {
-        "ask": _("can"),
-        "deny": _("can not")
-    }
+
+    ACTION_CHOICES = {"ask": _("can"), "deny": _("can not")}
 
     def __init__(self, rule: Rule):
         """
@@ -195,15 +205,14 @@ class RuleSimpleNoAllow(RuleSimple):
         """
         super().__init__(rule)
 
-        if str(rule.action) not in ['ask', 'deny'] or rule.argument is not None:
-            raise ValueError(_('Unrecognized action: ') + str(rule.action))
+        if str(rule.action) not in ["ask", "deny"] or rule.argument is not None:
+            raise ValueError(_("Unrecognized action: ") + str(rule.action))
 
     @staticmethod
-    def get_rule_errors(source: str, target: str, action: str) -> \
-            Optional[str]:
+    def get_rule_errors(source: str, target: str, action: str) -> Optional[str]:
         # action must be a simple ask/allow/deny
-        if action not in ['ask', 'deny']:
-            return _('Unrecognized action: ') + action
+        if action not in ["ask", "deny"]:
+            return _("Unrecognized action: ") + action
         return None
 
 
@@ -216,10 +225,11 @@ class RuleTargetedAdminVM(AbstractRuleWrapper):
     - if action is ask, wrapped rule must have default_target=@adminvm
     Returns strings as target/source/action. Target is not settable.
     """
+
     ACTION_CHOICES = {
         "ask": _("enable"),
         "allow": _("allow"),
-        "deny": _("disable")
+        "deny": _("disable"),
     }
 
     def __init__(self, rule: Rule):
@@ -229,24 +239,22 @@ class RuleTargetedAdminVM(AbstractRuleWrapper):
         super().__init__(rule)
         if rule.argument is not None:
             raise ValueError(_("Rule cannot have an argument"))
-        if rule.target != '@adminvm':
-            raise ValueError(_('Target must be @adminvm'))
+        if rule.target != "@adminvm":
+            raise ValueError(_("Target must be @adminvm"))
         if isinstance(rule.action, Ask):
-            if rule.action.default_target != '@adminvm':
-                raise ValueError(_('If action is ask, '
-                                   'default_target must be @adminvm'))
+            if rule.action.default_target != "@adminvm":
+                raise ValueError(_("If action is ask, default_target must be @adminvm"))
         if isinstance(rule.action, Allow):
             if rule.action.target:
-                raise ValueError(_('If action is allow, no '
-                                   'parameters are allowed'))
+                raise ValueError(_("If action is allow, no parameters are allowed"))
 
     @property
     def target(self):
-        return '@adminvm'
+        return "@adminvm"
 
     @target.setter
     def target(self, new_value):
-        raise ValueError(_('Cannot set target on this type of rule.'))
+        raise ValueError(_("Cannot set target on this type of rule."))
 
     @property
     def source(self):
@@ -265,8 +273,8 @@ class RuleTargetedAdminVM(AbstractRuleWrapper):
     def action(self, new_value):
         new_action = Action[new_value].value(self._rule)
         self._rule.action = new_action
-        if new_value == 'ask':
-            self._rule.action.default_target = '@adminvm'
+        if new_value == "ask":
+            self._rule.action.default_target = "@adminvm"
 
     @property
     def raw_rule(self):
@@ -285,10 +293,11 @@ class RuleTargeted(AbstractRuleWrapper):
         - else use original rule's normal target
     Returns and accepts strings as target/source/action.
     """
+
     ACTION_CHOICES = {
         "ask": _("ask"),
         "allow": _("automatically"),
-        "deny": _("never")
+        "deny": _("never"),
     }
 
     def __init__(self, rule: Rule):
@@ -298,18 +307,19 @@ class RuleTargeted(AbstractRuleWrapper):
         super().__init__(rule)
         if rule.argument is not None:
             raise ValueError(_("Rule cannot have an argument"))
-        errors = self.get_rule_errors(str(rule.source), str(rule.target),
-                                str(rule.action))
+        errors = self.get_rule_errors(
+            str(rule.source), str(rule.target), str(rule.action)
+        )
         if errors:
             raise ValueError(errors)
 
     @property
     def target(self):
         if isinstance(self._rule.action, Ask):
-            if self._rule.target == '@default':
+            if self._rule.target == "@default":
                 return str(self._rule.action.default_target)
         if isinstance(self._rule.action, Allow):
-            if self._rule.target == '@default':
+            if self._rule.target == "@default":
                 return str(self._rule.action.target)
         return str(self._rule.target)
 
@@ -317,20 +327,20 @@ class RuleTargeted(AbstractRuleWrapper):
     def target(self, new_value):
         new_target = Target(new_value)
 
-        if new_value.startswith('@'):
+        if new_value.startswith("@"):
             self._rule.target = new_target
-            if hasattr(self._rule.action, 'target'):
+            if hasattr(self._rule.action, "target"):
                 self._rule.action.target = None
-            if hasattr(self._rule.action, 'default_target'):
+            if hasattr(self._rule.action, "default_target"):
                 self._rule.action.default_target = None
             return
 
         if isinstance(self._rule.action, Ask):
-            self._rule.target = Target('@default')
+            self._rule.target = Target("@default")
             self._rule.action.default_target = new_target
             return
         if isinstance(self._rule.action, Allow):
-            self._rule.target = Target('@default')
+            self._rule.target = Target("@default")
             self._rule.action.target = new_target
             return
 
@@ -363,27 +373,29 @@ class RuleTargeted(AbstractRuleWrapper):
     def is_rule_fundamental(self) -> bool:
         if super().is_rule_fundamental():
             return True
-        return self.source == '@anyvm' and self.raw_rule.target == '@dispvm'
+        return self.source == "@anyvm" and self.raw_rule.target == "@dispvm"
 
     @staticmethod
     def get_rule_errors(source: str, target: str, action: str) -> Optional[str]:
-        if not source.startswith('@'):
-            if target.startswith('@') and target != '@dispvm':
-                if action in ('ask', 'allow'):
-                    return _('This type of action supports only single-qube '
-                             'destination qubes for single-qube source qubes.')
+        if not source.startswith("@"):
+            if target.startswith("@") and target != "@dispvm":
+                if action in ("ask", "allow"):
+                    return _(
+                        "This type of action supports only single-qube "
+                        "destination qubes for single-qube source qubes."
+                    )
         return None
 
-    def is_rule_conflicting(self, other_source: str, other_target: str,
-                            other_action: str) -> bool:
+    def is_rule_conflicting(
+        self, other_source: str, other_target: str, other_action: str
+    ) -> bool:
         """
         Return True if rule with other_source and other_target would conflict
          with self.
         """
-        if super().is_rule_conflicting(other_source, other_target,
-                                       other_action):
+        if super().is_rule_conflicting(other_source, other_target, other_action):
             return True
-        if self.action == 'allow' and other_source == self.source:
+        if self.action == "allow" and other_source == self.source:
             return True
         return False
 
@@ -400,11 +412,9 @@ class RuleDispVM(AbstractRuleWrapper):
     @dispvm:target_name, or @dispvm if it's default dispvm
     Returns and accepts strings as target/source/action.
     """
-    ACTION_CHOICES = {
-        "ask": _("ask"),
-        "allow": _("always"),
-        "deny": _("never")
-    }
+
+    ACTION_CHOICES = {"ask": _("ask"), "allow": _("always"), "deny": _("never")}
+
     def __init__(self, rule: Rule):
         """
         :param rule: Rule object
@@ -414,33 +424,34 @@ class RuleDispVM(AbstractRuleWrapper):
         if rule.argument is not None:
             raise ValueError(_("Rule cannot have an argument"))
 
-        if str(rule.target) != '@dispvm':
-            raise ValueError('Target must be @dispvm')
+        if str(rule.target) != "@dispvm":
+            raise ValueError("Target must be @dispvm")
 
-        if isinstance(rule.action, Ask) and \
-                not isinstance(rule.action.default_target,
-                               (DispVM, DispVMTemplate)):
+        if isinstance(rule.action, Ask) and not isinstance(
+            rule.action.default_target, (DispVM, DispVMTemplate)
+        ):
             raise ValueError("default_target must include @dispvm")
-        if isinstance(rule.action, Allow) and \
-                not isinstance(rule.action.target, (DispVM, DispVMTemplate)):
+        if isinstance(rule.action, Allow) and not isinstance(
+            rule.action.target, (DispVM, DispVMTemplate)
+        ):
             raise ValueError("target must include @dispvm")
 
     @property
     def target(self):
         target = ""
         if isinstance(self._rule.action, Ask):
-            target = str(self._rule.action.default_target or '')
+            target = str(self._rule.action.default_target or "")
         if isinstance(self._rule.action, Allow):
-            target = str(self._rule.action.target or '')
+            target = str(self._rule.action.target or "")
         if target.startswith("@dispvm:"):
-            target = target[len("@dispvm:"):]
+            target = target[len("@dispvm:") :]
         return target
 
     @target.setter
     def target(self, new_value):
         # when setting to a non-@dispvm, append @dispvm: at the start
-        if not new_value.startswith('@dispvm'):
-            new_value = '@dispvm:' + new_value
+        if not new_value.startswith("@dispvm"):
+            new_value = "@dispvm:" + new_value
         new_target = Target(new_value)
 
         if isinstance(self._rule.action, Ask):
@@ -449,7 +460,7 @@ class RuleDispVM(AbstractRuleWrapper):
         if isinstance(self._rule.action, Allow):
             self._rule.action.target = new_target
             return
-        return # deny has no target
+        return  # deny has no target
 
     @property
     def source(self):
@@ -466,13 +477,13 @@ class RuleDispVM(AbstractRuleWrapper):
 
     @action.setter
     def action(self, new_value):
-        if self.action == 'deny':
-            old_target = '@dispvm'
+        if self.action == "deny":
+            old_target = "@dispvm"
         else:
             old_target = self.target
         new_action = Action[new_value].value(self._rule)
         self._rule.action = new_action
-        if new_value != 'deny':
+        if new_value != "deny":
             # when switching from anything to deny,
             # there is no need to change target
             self.target = old_target
@@ -484,8 +495,9 @@ class RuleDispVM(AbstractRuleWrapper):
     def is_rule_fundamental(self) -> bool:
         return False
 
-    def is_rule_conflicting(self, other_source: str, other_target: str,
-                            other_action: str) -> bool:
+    def is_rule_conflicting(
+        self, other_source: str, other_target: str, other_action: str
+    ) -> bool:
         """
         Return True if rule with other_source and other_target would conflict
          with self.
@@ -497,7 +509,8 @@ class RuleDispVM(AbstractRuleWrapper):
 
 class AbstractVerbDescription(abc.ABC):
     """Class used to represent human-readable verb descriptions:
-        Qube1 (will) ACTION (verb_description) Qube2"""
+    Qube1 (will) ACTION (verb_description) Qube2"""
+
     @abc.abstractmethod
     def get_verb_for_action_and_target(self, action: str, target: str) -> str:
         """
@@ -508,6 +521,7 @@ class AbstractVerbDescription(abc.ABC):
 class SimpleVerbDescription(AbstractVerbDescription):
     """Simplest verb description, where a given Action has one corresponding
     description"""
+
     def __init__(self, descr: Dict[str, str]):
         """
         :param descr: Dict of action: description, where action is one of
@@ -526,8 +540,12 @@ class SimpleVerbDescription(AbstractVerbDescription):
 class TargetedVerbDescription(AbstractVerbDescription):
     """Verb description for more complex cases using target= and
     default_target."""
-    def __init__(self, single_target_descr: Dict[str, str],
-                multi_target_descr: Dict[str, str]):
+
+    def __init__(
+        self,
+        single_target_descr: Dict[str, str],
+        multi_target_descr: Dict[str, str],
+    ):
         """
         Both parameters are dicts of action: description, where action is one of
         ask, allow, deny
@@ -539,13 +557,16 @@ class TargetedVerbDescription(AbstractVerbDescription):
         self.multi_target_descr = multi_target_descr
 
         self.max_length = max(
-            (len(x) for x in [*self.single_target_descr.values(),
-                              *self.multi_target_descr.values()]))
-
+            (
+                len(x)
+                for x in [
+                    *self.single_target_descr.values(),
+                    *self.multi_target_descr.values(),
+                ]
+            )
+        )
 
     def get_verb_for_action_and_target(self, action: str, target: str) -> str:
-        if target.startswith('@') and target != '@dispvm':
-            return self.multi_target_descr.get(action, "").rjust(
-                self.max_length, " ")
-        return self.single_target_descr.get(action, "").rjust(
-            self.max_length, " ")
+        if target.startswith("@") and target != "@dispvm":
+            return self.multi_target_descr.get(action, "").rjust(self.max_length, " ")
+        return self.single_target_descr.get(action, "").rjust(self.max_length, " ")
