@@ -24,32 +24,37 @@
 import time
 from unittest.mock import patch
 
-from ...new_qube.application_selector import ApplicationBoxHandler, \
-    ApplicationButton, AddButton, ApplicationRow
+from ...new_qube.application_selector import (
+    ApplicationBoxHandler,
+    ApplicationButton,
+    AddButton,
+    ApplicationRow,
+)
 from ...new_qube.template_handler import TemplateHandler
 
 
-
-@patch('subprocess.check_output')
+@patch("subprocess.check_output")
 def test_app_handler(mock_subprocess, test_qapp, new_qube_builder):
     def mock_output(command):
         vm_name = command[-1]
-        if command[1] == '--get-available':
-            if vm_name == 'fedora-35':
-                return b'test.desktop|Test App|'
-            if vm_name == 'fedora-36':
-                return b'test2.desktop|Test2 App|test2 desc\n' \
-                       b'egg.desktop|Egg|egg\n' \
-                       b'firefox.desktop|Firefox|firefox'
-        elif command[1] == '--get-default-whitelist':
-            if vm_name == 'fedora-36':
-                return b'firefox.desktop'
-        return b''
+        if command[1] == "--get-available":
+            if vm_name == "fedora-35":
+                return b"test.desktop|Test App|"
+            if vm_name == "fedora-36":
+                return (
+                    b"test2.desktop|Test2 App|test2 desc\n"
+                    b"egg.desktop|Egg|egg\n"
+                    b"firefox.desktop|Firefox|firefox"
+                )
+        elif command[1] == "--get-default-whitelist":
+            if vm_name == "fedora-36":
+                return b"firefox.desktop"
+        return b""
+
     mock_subprocess.side_effect = mock_output
 
     template_handler = TemplateHandler(new_qube_builder, test_qapp)
-    assert template_handler.get_selected_template() == \
-           test_qapp.domains['fedora-36']
+    assert template_handler.get_selected_template() == test_qapp.domains["fedora-36"]
     app_selector = ApplicationBoxHandler(new_qube_builder, template_handler)
 
     # default template is selected at start, so:
@@ -59,11 +64,11 @@ def test_app_handler(mock_subprocess, test_qapp, new_qube_builder):
 
     for child in app_selector.flowbox.get_children():
         if isinstance(child, ApplicationButton):
-            assert child.appdata.name == 'Firefox'
+            assert child.appdata.name == "Firefox"
             continue
         assert isinstance(child, AddButton)
 
-    assert app_selector.get_selected_apps() == ['firefox.desktop']
+    assert app_selector.get_selected_apps() == ["firefox.desktop"]
 
     available_apps = []
     for row in app_selector.apps_list.get_children():
@@ -71,29 +76,31 @@ def test_app_handler(mock_subprocess, test_qapp, new_qube_builder):
         available_apps.append(row.appdata.ident)
 
     # order depends on selection
-    assert available_apps == ['firefox.desktop','egg.desktop', 'test2.desktop']
+    assert available_apps == ["firefox.desktop", "egg.desktop", "test2.desktop"]
 
 
-@patch('subprocess.check_output')
+@patch("subprocess.check_output")
 def test_app_handler_show_hide(mock_subprocess, test_qapp, new_qube_builder):
     def mock_output(command):
         vm_name = command[-1]
-        if command[1] == '--get-available':
-            if vm_name == 'fedora-35':
-                return b'test.desktop|Test App|'
-            if vm_name == 'fedora-36':
-                return b'test2.desktop|Test2 App|test2 desc\n' \
-                       b'egg.desktop|Egg|egg\n' \
-                       b'firefox.desktop|Firefox|firefox'
-        elif command[1] == '--get-default-whitelist':
-            if vm_name == 'fedora-36':
-                return b'firefox.desktop'
-        return b''
+        if command[1] == "--get-available":
+            if vm_name == "fedora-35":
+                return b"test.desktop|Test App|"
+            if vm_name == "fedora-36":
+                return (
+                    b"test2.desktop|Test2 App|test2 desc\n"
+                    b"egg.desktop|Egg|egg\n"
+                    b"firefox.desktop|Firefox|firefox"
+                )
+        elif command[1] == "--get-default-whitelist":
+            if vm_name == "fedora-36":
+                return b"firefox.desktop"
+        return b""
+
     mock_subprocess.side_effect = mock_output
 
     template_handler = TemplateHandler(new_qube_builder, test_qapp)
-    assert template_handler.get_selected_template() == \
-           test_qapp.domains['fedora-36']
+    assert template_handler.get_selected_template() == test_qapp.domains["fedora-36"]
     app_selector = ApplicationBoxHandler(new_qube_builder, template_handler)
 
     # click the plus button
@@ -109,13 +116,15 @@ def test_app_handler_show_hide(mock_subprocess, test_qapp, new_qube_builder):
     # select another row:
     for row in app_selector.apps_list.get_children():
         assert isinstance(row, ApplicationRow)
-        if row.appdata.name == 'Egg':
+        if row.appdata.name == "Egg":
             row.activate()
 
     app_selector.apps_close.clicked()
 
-    assert app_selector.get_selected_apps() == ['egg.desktop',
-                                                'firefox.desktop']
+    assert app_selector.get_selected_apps() == [
+        "egg.desktop",
+        "firefox.desktop",
+    ]
     assert len(app_selector.flowbox.get_children()) == 3
 
     # and try again, now deselect something and select something else
@@ -128,45 +137,50 @@ def test_app_handler_show_hide(mock_subprocess, test_qapp, new_qube_builder):
 
     for row in app_selector.apps_list.get_children():
         assert isinstance(row, ApplicationRow)
-        if row.appdata.name in ('Egg', 'Test2 App'):
+        if row.appdata.name in ("Egg", "Test2 App"):
             row.activate()
 
     app_selector.apps_close.clicked()
 
-    assert app_selector.get_selected_apps() == ['firefox.desktop',
-                                                'test2.desktop']
+    assert app_selector.get_selected_apps() == [
+        "firefox.desktop",
+        "test2.desktop",
+    ]
     assert len(app_selector.flowbox.get_children()) == 3
 
 
-@patch('subprocess.check_output')
-def test_app_handler_change_template(mock_subprocess,
-                                     test_qapp, new_qube_builder):
+@patch("subprocess.check_output")
+def test_app_handler_change_template(mock_subprocess, test_qapp, new_qube_builder):
     def mock_output(command):
         vm_name = command[-1]
-        if command[1] == '--get-available':
-            if vm_name == 'fedora-35':
-                return b'test.desktop|Test App|\n' \
-                       b'tomato.desktop|Tomato|basil\n' \
-                       b'udon.desktop|Udon|noodles\n' \
-                       b'spaghetti.desktop|Spaghetti|pasta'
-            if vm_name == 'fedora-36':
-                return b'test2.desktop|Test2 App|test2 desc\n' \
-                       b'egg.desktop|Egg|egg\n' \
-                       b'firefox.desktop|Firefox|firefox'
-        elif command[1] == '--get-default-whitelist':
-            if vm_name == 'fedora-36':
-                return b'firefox.desktop'
-        return b''
+        if command[1] == "--get-available":
+            if vm_name == "fedora-35":
+                return (
+                    b"test.desktop|Test App|\n"
+                    b"tomato.desktop|Tomato|basil\n"
+                    b"udon.desktop|Udon|noodles\n"
+                    b"spaghetti.desktop|Spaghetti|pasta"
+                )
+            if vm_name == "fedora-36":
+                return (
+                    b"test2.desktop|Test2 App|test2 desc\n"
+                    b"egg.desktop|Egg|egg\n"
+                    b"firefox.desktop|Firefox|firefox"
+                )
+        elif command[1] == "--get-default-whitelist":
+            if vm_name == "fedora-36":
+                return b"firefox.desktop"
+        return b""
+
     mock_subprocess.side_effect = mock_output
 
     template_handler = TemplateHandler(new_qube_builder, test_qapp)
-    assert template_handler.get_selected_template() == \
-           test_qapp.domains['fedora-36']
+    assert template_handler.get_selected_template() == test_qapp.domains["fedora-36"]
     app_selector = ApplicationBoxHandler(new_qube_builder, template_handler)
 
-    assert app_selector.get_selected_apps() == ['firefox.desktop']
+    assert app_selector.get_selected_apps() == ["firefox.desktop"]
 
-    template_handler.select_template('fedora-35')
+    template_handler.select_template("fedora-35")
 
     for child in app_selector.flowbox.get_children():
         if isinstance(child, AddButton):
@@ -177,16 +191,18 @@ def test_app_handler_change_template(mock_subprocess,
 
     for row in app_selector.apps_list.get_children():
         assert isinstance(row, ApplicationRow)
-        if row.appdata.name in ('Udon', 'Spaghetti'):
+        if row.appdata.name in ("Udon", "Spaghetti"):
             row.activate()
 
     app_selector.apps_close.clicked()
 
-    assert app_selector.get_selected_apps() == ['spaghetti.desktop',
-                                                'udon.desktop']
+    assert app_selector.get_selected_apps() == [
+        "spaghetti.desktop",
+        "udon.desktop",
+    ]
 
     # default is none
-    template_handler.change_vm_type('qube_type_template')
+    template_handler.change_vm_type("qube_type_template")
     assert template_handler.get_selected_template() is None
 
     assert not app_selector.flowbox.get_visible()
@@ -194,7 +210,7 @@ def test_app_handler_change_template(mock_subprocess,
     assert not app_selector.get_selected_apps()
 
     # select some apps
-    template_handler.select_template('fedora-35')
+    template_handler.select_template("fedora-35")
     for child in app_selector.flowbox.get_children():
         if isinstance(child, AddButton):
             child.activate()
@@ -204,43 +220,48 @@ def test_app_handler_change_template(mock_subprocess,
 
     for row in app_selector.apps_list.get_children():
         assert isinstance(row, ApplicationRow)
-        if row.appdata.name in ('Udon', 'Spaghetti'):
+        if row.appdata.name in ("Udon", "Spaghetti"):
             row.activate()
 
     app_selector.apps_close.clicked()
 
-    assert app_selector.get_selected_apps() == ['spaghetti.desktop',
-                                                'udon.desktop']
+    assert app_selector.get_selected_apps() == [
+        "spaghetti.desktop",
+        "udon.desktop",
+    ]
 
     # and now go back to none
     template_handler.select_template(None)
     assert not app_selector.get_selected_apps()
 
 
-@patch('subprocess.check_output')
-def test_app_handler_do_template(mock_subprocess,
-                                     test_qapp, new_qube_builder):
+@patch("subprocess.check_output")
+def test_app_handler_do_template(mock_subprocess, test_qapp, new_qube_builder):
     def mock_output(command):
         vm_name = command[-1]
-        if command[1] == '--get-available':
-            if vm_name == 'fedora-35':
-                return b'test.desktop|Test App|\n' \
-                       b'tomato.desktop|Tomato|basil\n' \
-                       b'udon.desktop|Udon|noodles\n' \
-                       b'spaghetti.desktop|Spaghetti|pasta'
-            if vm_name == 'fedora-36':
-                return b'test2.desktop|Test2 App|test2 desc\n' \
-                       b'egg.desktop|Egg|egg\n' \
-                       b'firefox.desktop|Firefox|firefox'
-        elif command[1] == '--get-default-whitelist':
-            if vm_name == 'fedora-36':
-                return b'firefox.desktop'
-        return b''
+        if command[1] == "--get-available":
+            if vm_name == "fedora-35":
+                return (
+                    b"test.desktop|Test App|\n"
+                    b"tomato.desktop|Tomato|basil\n"
+                    b"udon.desktop|Udon|noodles\n"
+                    b"spaghetti.desktop|Spaghetti|pasta"
+                )
+            if vm_name == "fedora-36":
+                return (
+                    b"test2.desktop|Test2 App|test2 desc\n"
+                    b"egg.desktop|Egg|egg\n"
+                    b"firefox.desktop|Firefox|firefox"
+                )
+        elif command[1] == "--get-default-whitelist":
+            if vm_name == "fedora-36":
+                return b"firefox.desktop"
+        return b""
+
     mock_subprocess.side_effect = mock_output
 
     template_handler = TemplateHandler(new_qube_builder, test_qapp)
-    assert template_handler.get_selected_template() == \
-           test_qapp.domains['fedora-36']
+    assert template_handler.get_selected_template() == test_qapp.domains["fedora-36"]
     app_selector = ApplicationBoxHandler(new_qube_builder, template_handler)
 
     for child in app_selector.flowbox.get_children():
@@ -251,7 +272,7 @@ def test_app_handler_do_template(mock_subprocess,
         assert False  # button not found
 
     # try to find Udon
-    app_selector.apps_search.set_text('Udon')
+    app_selector.apps_search.set_text("Udon")
 
     assert app_selector.apps_list_placeholder.get_visible()
     app_selector.load_all_button.clicked()
@@ -265,46 +286,50 @@ def test_app_handler_do_template(mock_subprocess,
 
             # the widget in ask window should have been changed to new tmpl
             assert app_selector.target_template_name_widget
-            assert app_selector.target_template_name_widget.vm == \
-                   test_qapp.domains['fedora-35']
+            assert (
+                app_selector.target_template_name_widget.vm
+                == test_qapp.domains["fedora-35"]
+            )
             app_selector.change_template_ok.clicked()
             break
     else:
         assert False  # didn't find udon
 
-    assert template_handler.get_selected_template() == \
-           test_qapp.domains['fedora-35']
+    assert template_handler.get_selected_template() == test_qapp.domains["fedora-35"]
 
 
-@patch('subprocess.check_output')
-def test_app_handler_delete(mock_subprocess,
-                            test_qapp, new_qube_builder):
+@patch("subprocess.check_output")
+def test_app_handler_delete(mock_subprocess, test_qapp, new_qube_builder):
     def mock_output(command):
         vm_name = command[-1]
-        if command[1] == '--get-available':
-            if vm_name == 'fedora-35':
-                return b'test.desktop|Test App|\n' \
-                       b'tomato.desktop|Tomato|basil\n' \
-                       b'udon.desktop|Udon|noodles\n' \
-                       b'spaghetti.desktop|Spaghetti|pasta'
-            if vm_name == 'fedora-36':
-                return b'test2.desktop|Test2 App|test2 desc\n' \
-                       b'egg.desktop|Egg|egg\n' \
-                       b'firefox.desktop|Firefox|firefox'
-        elif command[1] == '--get-default-whitelist':
-            if vm_name == 'fedora-36':
-                return b'firefox.desktop'
-        return b''
+        if command[1] == "--get-available":
+            if vm_name == "fedora-35":
+                return (
+                    b"test.desktop|Test App|\n"
+                    b"tomato.desktop|Tomato|basil\n"
+                    b"udon.desktop|Udon|noodles\n"
+                    b"spaghetti.desktop|Spaghetti|pasta"
+                )
+            if vm_name == "fedora-36":
+                return (
+                    b"test2.desktop|Test2 App|test2 desc\n"
+                    b"egg.desktop|Egg|egg\n"
+                    b"firefox.desktop|Firefox|firefox"
+                )
+        elif command[1] == "--get-default-whitelist":
+            if vm_name == "fedora-36":
+                return b"firefox.desktop"
+        return b""
+
     mock_subprocess.side_effect = mock_output
 
     template_handler = TemplateHandler(new_qube_builder, test_qapp)
-    assert template_handler.get_selected_template() == \
-           test_qapp.domains['fedora-36']
+    assert template_handler.get_selected_template() == test_qapp.domains["fedora-36"]
     app_selector = ApplicationBoxHandler(new_qube_builder, template_handler)
 
-    assert app_selector.get_selected_apps() == ['firefox.desktop']
+    assert app_selector.get_selected_apps() == ["firefox.desktop"]
 
-    template_handler.select_template('fedora-35')
+    template_handler.select_template("fedora-35")
 
     for child in app_selector.flowbox.get_children():
         if isinstance(child, AddButton):
@@ -315,20 +340,22 @@ def test_app_handler_delete(mock_subprocess,
 
     for row in app_selector.apps_list.get_children():
         assert isinstance(row, ApplicationRow)
-        if row.appdata.name in ('Udon', 'Spaghetti'):
+        if row.appdata.name in ("Udon", "Spaghetti"):
             row.activate()
 
     app_selector.apps_close.clicked()
 
-    assert app_selector.get_selected_apps() == ['spaghetti.desktop',
-                                                'udon.desktop']
+    assert app_selector.get_selected_apps() == [
+        "spaghetti.desktop",
+        "udon.desktop",
+    ]
 
     for button in app_selector.flowbox.get_children():
         if isinstance(button, ApplicationButton):
-            if button.appdata.ident == 'udon.desktop':
+            if button.appdata.ident == "udon.desktop":
                 button.activate()
                 break
     else:
         assert False  # app button not found
 
-    assert app_selector.get_selected_apps() == ['spaghetti.desktop']
+    assert app_selector.get_selected_apps() == ["spaghetti.desktop"]
