@@ -28,34 +28,38 @@ from qrexec.policy.parser import Rule
 
 def test_conflict_files():
     def return_files(service_name):
-        if service_name == 'test':
+        if service_name == "test":
             return ["a-test", "b-test", "c-test"]
-        return ['']
+        return [""]
 
     manager = PolicyManager()
-    with patch("qubes_config.global_config.policy_manager."
-               "PolicyClient.policy_get_files") as mock_get:
+    with patch(
+        "qubes_config.global_config.policy_manager.PolicyClient.policy_get_files"
+    ) as mock_get:
         mock_get.side_effect = return_files
 
-        assert manager.get_conflicting_policy_files('test', 'd-test') == \
-               ["a-test", "b-test", "c-test"]
-        assert manager.get_conflicting_policy_files('test', 'c-test') == \
-               ["a-test", "b-test"]
-        assert manager.get_conflicting_policy_files('test', 'b-test') == \
-               ["a-test"]
-        assert not manager.get_conflicting_policy_files('test', 'a-test')
-        assert not manager.get_conflicting_policy_files('other', 'test')
+        assert manager.get_conflicting_policy_files("test", "d-test") == [
+            "a-test",
+            "b-test",
+            "c-test",
+        ]
+        assert manager.get_conflicting_policy_files("test", "c-test") == [
+            "a-test",
+            "b-test",
+        ]
+        assert manager.get_conflicting_policy_files("test", "b-test") == ["a-test"]
+        assert not manager.get_conflicting_policy_files("test", "a-test")
+        assert not manager.get_conflicting_policy_files("other", "test")
 
-@patch("qubes_config.global_config.policy_manager."
-               "PolicyClient.policy_get")
-@patch("qubes_config.global_config.policy_manager."
-               "PolicyClient.policy_replace")
+
+@patch("qubes_config.global_config.policy_manager.PolicyClient.policy_get")
+@patch("qubes_config.global_config.policy_manager.PolicyClient.policy_replace")
 def test_get_policy_from_file_new_no_default(mock_replace, mock_get):
     manager = PolicyManager()
 
-    mock_get.side_effect = subprocess.CalledProcessError(2, 'test')
+    mock_get.side_effect = subprocess.CalledProcessError(2, "test")
 
-    assert manager.get_rules_from_filename('test', '') == ([], None)
+    assert manager.get_rules_from_filename("test", "") == ([], None)
     assert not mock_replace.mock_calls
 
 
@@ -67,7 +71,7 @@ def test_get_policy_from_file_new():
         def policy_get(self, filename):
             if filename in self.files:
                 return self.files[filename], filename
-            raise subprocess.CalledProcessError(2, 'test')
+            raise subprocess.CalledProcessError(2, "test")
 
         def policy_replace(self, filename, text):
             self.files[filename] = text
@@ -75,37 +79,38 @@ def test_get_policy_from_file_new():
     manager = PolicyManager()
     manager.policy_client = MockPolicy()
 
-    test_default = 'Test\t*\t@anyvm\t@anyvm\tdeny'
+    test_default = "Test\t*\t@anyvm\t@anyvm\tdeny"
 
     # token should be None (the file is new), but rules should be appropriate
-    got_rules, token = manager.get_rules_from_filename('test', test_default)
+    got_rules, token = manager.get_rules_from_filename("test", test_default)
     assert token is None
     assert len(got_rules) == 1
     assert str(got_rules[0]) == test_default
-    assert 'test' not in manager.policy_client.files
+    assert "test" not in manager.policy_client.files
 
 
 def test_get_policy_from_file_existing():
     manager = PolicyManager()
 
-    rules = 'Test\t*\t@anyvm\t@anyvm\tdeny'
+    rules = "Test\t*\t@anyvm\t@anyvm\tdeny"
 
     def get_file(filename):
-        if filename == 'test':
-            return rules, 'test'
-        return '', ''
+        if filename == "test":
+            return rules, "test"
+        return "", ""
 
-    with patch("qubes_config.global_config.policy_manager."
-               "PolicyClient.policy_get") as mock_get:
+    with patch(
+        "qubes_config.global_config.policy_manager.PolicyClient.policy_get"
+    ) as mock_get:
         mock_get.side_effect = get_file
 
-        got_rules, token = manager.get_rules_from_filename('test', '')
-        assert token == 'test'
+        got_rules, token = manager.get_rules_from_filename("test", "")
+        assert token == "test"
         assert len(got_rules) == 1
         assert str(got_rules[0]) == rules
 
-        got_rules, token = manager.get_rules_from_filename('test2', '')
-        assert token == ''
+        got_rules, token = manager.get_rules_from_filename("test2", "")
+        assert token == ""
         assert len(got_rules) == 0
 
 
@@ -118,19 +123,16 @@ Test +Test2 work @anyvm allow"""
     rule_text_3 = """Test * @anyvm @anyvm deny
 Test * work @anyvm allow"""
 
-    rules_1 = [Rule.from_line(None, "Test * @anyvm @anyvm deny",
-                              filepath=None, lineno=0)]
+    rules_1 = [
+        Rule.from_line(None, "Test * @anyvm @anyvm deny", filepath=None, lineno=0)
+    ]
     rules_2 = [
-        Rule.from_line(None, "Test * @anyvm @anyvm deny",
-                       filepath=None, lineno=0),
-        Rule.from_line(None, "Test +Test2 work @anyvm allow",
-                       filepath=None, lineno=0)
+        Rule.from_line(None, "Test * @anyvm @anyvm deny", filepath=None, lineno=0),
+        Rule.from_line(None, "Test +Test2 work @anyvm allow", filepath=None, lineno=0),
     ]
     rules_3 = [
-        Rule.from_line(None, "Test * @anyvm @anyvm deny",
-                       filepath=None, lineno=0),
-        Rule.from_line(None, "Test * work @anyvm allow",
-                       filepath=None, lineno=0)
+        Rule.from_line(None, "Test * @anyvm @anyvm deny", filepath=None, lineno=0),
+        Rule.from_line(None, "Test * work @anyvm allow", filepath=None, lineno=0),
     ]
 
     assert manager.compare_rules_to_text(rules_1, rule_text_1)
@@ -145,27 +147,34 @@ Test * work @anyvm allow"""
 def test_new_rule():
     manager = PolicyManager()
 
-    rule_1 = Rule.from_line(
-        None, "Test * @anyvm @anyvm deny", filepath=None, lineno=0)
+    rule_1 = Rule.from_line(None, "Test * @anyvm @anyvm deny", filepath=None, lineno=0)
     rule_2 = Rule.from_line(
-        None, "Test +Test @anyvm vault allow target=dom0",
-        filepath=None, lineno=0)
+        None,
+        "Test +Test @anyvm vault allow target=dom0",
+        filepath=None,
+        lineno=0,
+    )
+
+    assert str(manager.new_rule("Test", "@anyvm", "@anyvm", "deny")) == str(rule_1)
+    assert str(
+        manager.new_rule(
+            service="Test",
+            source="@anyvm",
+            target="vault",
+            action="allow target=dom0",
+            argument="+Test",
+        )
+    ) == str(rule_2)
 
-    assert str(manager.new_rule('Test', '@anyvm', '@anyvm', 'deny')) == \
-           str(rule_1)
-    assert str(manager.new_rule(
-        service='Test', source='@anyvm', target='vault',
-        action='allow target=dom0', argument='+Test')) == str(rule_2)
 
 def test_save_policy():
     manager = PolicyManager()
 
-    rule_text = 'Test\t*\t@anyvm\t@anyvm\tdeny'
-    rule = Rule.from_line(
-        None, "Test * @anyvm @anyvm deny", filepath=None, lineno=0)
+    rule_text = "Test\t*\t@anyvm\t@anyvm\tdeny"
+    rule = Rule.from_line(None, "Test * @anyvm @anyvm deny", filepath=None, lineno=0)
 
     def replace_file(file_name: str, new_text: str, _token):
-        if file_name == 'test':
+        if file_name == "test":
             if not new_text.startswith(manager.policy_disclaimer):
                 assert False
             if not rule_text in new_text:
@@ -173,7 +182,8 @@ def test_save_policy():
             return
         assert False
 
-    with patch("qubes_config.global_config.policy_manager."
-               "PolicyClient.policy_replace") as mock_replace:
+    with patch(
+        "qubes_config.global_config.policy_manager.PolicyClient.policy_replace"
+    ) as mock_replace:
         mock_replace.side_effect = replace_file
-        manager.save_rules('test', [rule], 'any')
+        manager.save_rules("test", [rule], "any")
