@@ -24,7 +24,7 @@ import qubesadmin.exc
 import qubesadmin.devices
 import qubesadmin.vm
 from qubesadmin.utils import size_to_human
-from qubesadmin.device_protocol import DeviceAssignment, DeviceCategory
+from qubesadmin.device_protocol import DeviceAssignment, DeviceCategory, DeviceInterface
 
 import gi
 
@@ -38,6 +38,7 @@ _ = t.gettext
 
 FEATURE_HIDE_CHILDREN = "device-hide-children"
 FEATURE_ATTACH_WITH_MIC = "device-attach-with-mic"
+FEATURE_RESOLUTION = "device-qvc-resolution"  # dev_id=resolution, space delimited
 
 
 class VM:
@@ -50,9 +51,12 @@ class VM:
         self._vm = vm
         self.name = vm.name
         self.vm_class = vm.klass
+        self._devices_denied = []
         self.is_running = True  # in most cases, this is just True, unless we're at
         # sysusb
 
+        self.update_denied_devices()
+
     def __str__(self):
         return self.name
 
@@ -130,17 +134,30 @@ class VM:
         new_feature = " ".join(all_devs)
         self._vm.features[feature_name] = new_feature
 
+    @property
+    def devices_denied(self) -> List[DeviceInterface]:
+        return self._devices_denied
+
+    def update_denied_devices(self):
+        try:
+            self._devices_denied = DeviceInterface.from_str_bulk(
+                self._vm.devices_denied
+            )
+        except AttributeError:
+            self._devices_denied = []
+
 
 class Device:
     @classmethod
     def id_from_device(cls, dev: qubesadmin.devices.DeviceInfo) -> str:
-        return str(dev.port) + ":" + str(dev.device_id)
+        return str(dev.devclass) + ":" + str(dev.port) + ":" + str(dev.device_id)
 
     def __init__(self, dev: qubesadmin.devices.DeviceInfo, gtk_app: Gtk.Application):
         self.gtk_app: Gtk.Application = gtk_app
         self._dev: qubesadmin.devices.DeviceInfo = dev
         self.__hash = hash(dev)
         self._port: str = str(dev.port)
+        self._interfaces = dev.interfaces
         # Monotonic connection timestamp only for new devices
         self.connection_timestamp: float = None
 
@@ -152,7 +169,6 @@ class Device:
         self._description: str = getattr(dev, "description", "unknown")
         self._devclass: str = getattr(dev, "devclass", "unknown")
 
-        main_category = None
         for interface in dev.interfaces:
             if interface.category.name != "Other":
                 main_category = interface.category
@@ -164,6 +180,7 @@ class Device:
 
         self._data: Dict = getattr(dev, "data", {})
         self._device_id = getattr(dev, "device_id", "*")
+        self.options = {}
         self.parent = str(getattr(dev, "parent_device", None) or "")
         self.attachments: Set[VM] = set()
         self.assignments: Set[VM] = set()
@@ -186,6 +203,20 @@ class Device:
         self.show_children: bool = True
         self.hide_this_device: bool = False
 
+        if self.device_class == "webcam" and self._backend_domain:
+            resolution_feature = self._backend_domain.vm_object.features.get(
+                FEATURE_RESOLUTION, ""
+            )
+            if resolution_feature:
+                for w in resolution_feature.split(" "):
+                    try:
+                        k, v = w.split("=")
+                        if k == self.id_string:
+                            self.options["format"] = v
+                    except ValueError:
+                        # malformed options, ignore them
+                        pass
+
     def __str__(self):
         return self._dev_name
 
@@ -286,6 +317,7 @@ class Device:
                 port_id=self._ident,
                 devclass=self.device_class,
                 device_id=self._device_id,
+                options=self.options,
             )
             vm.vm_object.devices[self.device_class].attach(assignment)
             self.gtk_app.emit_notification(
@@ -353,3 +385,10 @@ class Device:
         """
         for vm in self.attachments:
             self.detach_from_vm(vm, with_aux_devices)
+
+    def is_valid_for_vm(self, vm: VM):
+        for deny_interface in vm.devices_denied:
+            for interface in self._interfaces:
+                if deny_interface.matches(interface):
+                    return False
+        return True
