@@ -65,7 +65,7 @@ _ = t.gettext
 
 
 # FUTURE: this should be moved to backend with new API changes
-DEV_TYPES = ["block", "usb", "mic"]
+DEV_TYPES = ["block", "usb", "mic", "webcam"]
 
 
 class DeviceMenu(Gtk.Menu):
@@ -112,6 +112,7 @@ class DevicesTray(Gtk.Application):
         self.vms: Set[backend.VM] = set()
         self.dispvm_templates: Set[backend.VM] = set()
         self.parent_ports_to_hide = []
+        self.cameras_to_hide = []
         self.active_usbvms: Set[backend.VM] = set()
         self.dormant_usbvms: Set[backend.VM] = set()
         self.dev_update_queue: Set = set()
@@ -157,7 +158,6 @@ class DevicesTray(Gtk.Application):
         self.dispatcher.add_handler(
             "property-set:template_for_dispvms", self.vm_dispvm_template_change
         )
-
         self.dispatcher.add_handler(
             "property-reset:template_for_dispvms",
             self.vm_dispvm_template_change,
@@ -165,6 +165,15 @@ class DevicesTray(Gtk.Application):
         self.dispatcher.add_handler(
             "property-del:template_for_dispvms", self.vm_dispvm_template_change
         )
+        self.dispatcher.add_handler(
+            "property-set:devices_denied", self.vm_denied_changed
+        )
+        self.dispatcher.add_handler(
+            "property-reset:devices_denied", self.vm_denied_changed
+        )
+        self.dispatcher.add_handler(
+            "property-del:devices_denied", self.vm_denied_changed
+        )
 
         self.dispatcher.add_handler(
             "domain-feature-set:internal", self.update_internal_feature
@@ -172,6 +181,13 @@ class DevicesTray(Gtk.Application):
         self.dispatcher.add_handler(
             "domain-feature-delete:internal", self.update_internal_feature
         )
+        self.dispatcher.add_handler(
+            "domain-feature-set:" + backend.FEATURE_RESOLUTION, self.update_resolution
+        )
+        self.dispatcher.add_handler(
+            "domain-feature-delete:" + backend.FEATURE_RESOLUTION,
+            self.update_resolution,
+        )
 
         for feature in [backend.FEATURE_HIDE_CHILDREN, backend.FEATURE_ATTACH_WITH_MIC]:
 
@@ -266,13 +282,17 @@ class DevicesTray(Gtk.Application):
         if dev.parent:
             for potential_parent in self.devices.values():
                 if potential_parent.port == dev.parent:
+                    # hide parents of webcams
+                    if dev.device_class == "webcam":
+                        self.cameras_to_hide.append(dev.parent)
+                        potential_parent.hide_this_device = True
                     potential_parent.has_children = True
                     break
 
         # connect with mic
         mic_feature = vm.features.get(backend.FEATURE_ATTACH_WITH_MIC, "").split(" ")
         if dev_id in mic_feature:
-            microphone = self.devices.get("dom0:mic:dom0:mic::m000000", None)
+            microphone = self.devices.get("mic:dom0:mic:dom0:mic::m000000", None)
             microphone.devices_to_attach_with_me.append(dev)
             dev.devices_to_attach_with_me = [microphone]
 
@@ -298,7 +318,7 @@ class DevicesTray(Gtk.Application):
             # we never knew the device anyway
             return
 
-        microphone = self.devices.get("dom0:mic:dom0:mic::m000000", None)
+        microphone = self.devices.get("mic:dom0:mic:dom0:mic::m000000", None)
 
         self.emit_notification(
             _("Device removed"),
@@ -310,6 +330,12 @@ class DevicesTray(Gtk.Application):
             microphone.devices_to_attach_with_me.remove(dev)
         if dev.port in self.parent_ports_to_hide:
             self.parent_ports_to_hide.remove(dev.port)
+        if dev.parent in self.cameras_to_hide:
+            for potential_parent in self.devices.values():
+                if potential_parent.port == dev.parent:
+                    potential_parent.hide_this_device = False
+                    break
+            self.cameras_to_hide.remove(dev.parent)
         del self.devices[dev_id]
 
     def initialize_dev_data(self):
@@ -351,6 +377,12 @@ class DevicesTray(Gtk.Application):
                     # we have no permission to access VM's devices
                     continue
 
+        # hide parents of webcams
+        for device in self.devices.values():
+            if device.device_class == "webcam":
+                if device.parent:
+                    self.cameras_to_hide.append(device.parent)
+
     def device_assigned(self, vm, _event, device, **_kwargs):
         dev_id = backend.Device.id_from_device(device)
         if dev_id not in self.devices:
@@ -399,7 +431,7 @@ class DevicesTray(Gtk.Application):
         add = new - old
         remove = old - new
 
-        microphone = self.devices.get("dom0:mic:dom0:mic::m000000", None)
+        microphone = self.devices.get("mic:dom0:mic:dom0:mic::m000000", None)
 
         for dev_name in remove:
             if feature == backend.FEATURE_ATTACH_WITH_MIC:
@@ -428,6 +460,29 @@ class DevicesTray(Gtk.Application):
                     self.parent_ports_to_hide.append(dev.port)
                     self.hide_child_devices(dev.port, False)
 
+    def update_resolution(self, vm, _event, feature, value=None, oldvalue=None):
+        # pylint: disable=unused-argument
+        res_dict = {}
+        if value:
+            for word in value.split(" "):
+                try:
+                    k, v = word.split("=")
+                    res_dict[k] = v
+                except ValueError:
+                    # the feature is malformed, ignore it
+                    res_dict = {}
+
+        for device in self.devices.values():
+            if (
+                device.device_class == "webcam"
+                and device.backend_domain.name == vm.name
+            ):
+                resolution = res_dict.get(device.id_string, None)
+                if resolution:
+                    device.options["format"] = resolution
+                elif "format" in device.options:
+                    del device.options["format"]
+
     def vm_unpaused(self, vm, _event, **_kwargs):
         wrapped_vm = backend.VM(vm)
         try:
@@ -465,7 +520,7 @@ class DevicesTray(Gtk.Application):
         """
         domains = self.qapp.domains
 
-        microphone = self.devices.get("dom0:mic:dom0:mic::m000000", None)
+        microphone = self.devices.get("mic:dom0:mic:dom0:mic::m000000", None)
         # clear existing feature mappings
         for dev in self.devices.values():
             dev.devices_to_attach_with_me = []
@@ -475,14 +530,25 @@ class DevicesTray(Gtk.Application):
         mic_dev_strings = []
         if microphone:
             for domain in domains:
-                mic_feature = domain.features.get(
-                    backend.FEATURE_ATTACH_WITH_MIC, False
-                )
-                if isinstance(mic_feature, str):
-                    mic_dev_strings.extend(
-                        [dev for dev in mic_feature.split(" ") if dev]
+                try:
+                    mic_feature = domain.features.get(
+                        backend.FEATURE_ATTACH_WITH_MIC, False
                     )
-
+                    if not mic_feature:
+                        continue
+                except qubesadmin.exc.QubesDaemonAccessError:
+                    continue
+                for dev in mic_feature.split(" "):
+                    if not dev:
+                        continue
+                    try:
+                        _class, vm_name, _rest = dev.split(":", 2)
+                        if vm_name != domain.name:
+                            continue
+                        mic_dev_strings.append(dev)
+                    except ValueError:
+                        # malformed name
+                        pass
             microphone.devices_to_attach_with_me = []
 
             for dev in mic_dev_strings:
@@ -493,7 +559,12 @@ class DevicesTray(Gtk.Application):
         self.parent_ports_to_hide = []
         parent_ids_to_hide = []
         for domain in domains:
-            children_feature = domain.features.get(backend.FEATURE_HIDE_CHILDREN, False)
+            try:
+                children_feature = domain.features.get(
+                    backend.FEATURE_HIDE_CHILDREN, False
+                )
+            except qubesadmin.exc.QubesDaemonAccessError:
+                continue
             if isinstance(children_feature, str):
                 parent_ids_to_hide.extend([s for s in children_feature.split(" ") if s])
 
@@ -503,6 +574,9 @@ class DevicesTray(Gtk.Application):
                 dev.show_children = False
 
         self.hide_child_devices()
+        for dev in self.devices.values():
+            if dev.port in self.cameras_to_hide:
+                dev.hide_this_device = True
 
     def hide_child_devices(
         self, parent_port: Optional[str] = None, state: bool = False
@@ -604,6 +678,13 @@ class DevicesTray(Gtk.Application):
         else:
             self.dispvm_templates.discard(wrapped_vm)
 
+    def vm_denied_changed(self, vm, _event, **_kwargs):
+        """devices_denied property changed"""
+        for wrapped_vm in self.vms:
+            if wrapped_vm.name == vm.name:
+                wrapped_vm.update_denied_devices()
+                return
+
     @staticmethod
     def load_css(widget) -> str:
         """Load appropriate css. This should be called whenever menu is shown,
