@@ -9,14 +9,19 @@ import time
 import importlib.resources
 import gi  # isort:skip
 
-from qubes_config.widgets.gtk_utils import load_icon_at_gtk_size, load_theme, \
-    show_dialog_with_icon, RESPONSES_OK
+from qubes_config.widgets.gtk_utils import (
+    load_icon_at_gtk_size,
+    load_theme,
+    show_dialog_with_icon,
+    RESPONSES_OK,
+)
 from qui.updater.progress_page import ProgressPage
 from qui.updater.updater_settings import Settings, OverriddenSettings
 from qui.updater.summary_page import SummaryPage
 from qui.updater.intro_page import IntroPage
+import qui.updater.utils
 
-gi.require_version('Gtk', '3.0')  # isort:skip
+gi.require_version("Gtk", "3.0")  # isort:skip
 from gi.repository import Gtk, Gdk, Gio  # isort:skip
 from qubesadmin import Qubes
 import qubesadmin.exc
@@ -27,7 +32,7 @@ import locale
 from locale import gettext as l
 
 locale.bindtextdomain("desktop-linux-manager", "/usr/locales/")
-locale.textdomain('desktop-linux-manager')
+locale.textdomain("desktop-linux-manager")
 
 
 class ArgumentError(Exception):
@@ -37,13 +42,13 @@ class ArgumentError(Exception):
 class QubesUpdater(Gtk.Application):
     # pylint: disable=too-many-instance-attributes
 
-    LOGPATH = '/var/log/qubes/qui.updater.log'
-    LOG_FORMAT = '%(asctime)s %(message)s'
+    LOGPATH = "/var/log/qubes/qui.updater.log"
+    LOG_FORMAT = "%(asctime)s %(message)s"
 
     def __init__(self, qapp, cliargs):
         super().__init__(
             application_id="org.gnome.example",
-            flags=Gio.ApplicationFlags.FLAGS_NONE
+            flags=Gio.ApplicationFlags.FLAGS_NONE,
         )
         self.qapp = qapp
         self.primary = False
@@ -52,12 +57,11 @@ class QubesUpdater(Gtk.Application):
         self.cliargs = cliargs
         self.retcode = 0
 
-        log_handler = logging.FileHandler(
-            QubesUpdater.LOGPATH, encoding='utf-8')
+        log_handler = logging.FileHandler(QubesUpdater.LOGPATH, encoding="utf-8")
         log_formatter = logging.Formatter(QubesUpdater.LOG_FORMAT)
         log_handler.setFormatter(log_formatter)
 
-        self.log = logging.getLogger('vm-update.agent.PackageManager')
+        self.log = logging.getLogger("vm-update.agent.PackageManager")
         self.log.addHandler(log_handler)
         self.log.setLevel(self.cliargs.log)
 
@@ -81,22 +85,23 @@ class QubesUpdater(Gtk.Application):
         self.builder = Gtk.Builder()
         self.builder.set_translation_domain("desktop-linux-manager")
 
-        glade_ref = (importlib.resources.files('qui') /
-                      'updater.glade')
+        glade_ref = importlib.resources.files("qui") / "updater.glade"
         with importlib.resources.as_file(glade_ref) as path:
             self.builder.add_from_file(str(path))
 
         self.main_window: Gtk.Window = self.builder.get_object("main_window")
         self.next_button: Gtk.Button = self.builder.get_object("button_next")
         self.next_button.connect("clicked", self.next_clicked)
-        self.cancel_button: Gtk.Button = self.builder.get_object(
-            "button_cancel")
+        self.cancel_button: Gtk.Button = self.builder.get_object("button_cancel")
         self.cancel_button.connect("clicked", self.cancel_clicked)
 
-        load_theme(widget=self.main_window,
-                   package_name='qui',
-                   light_file_name='qubes-updater-light.css',
-                   dark_file_name='qubes-updater-dark.css')
+        self.EffectiveCssProvider = load_theme(
+            widget=self.main_window,
+            package_name="qui",
+            light_file_name="qubes-updater-light.css",
+            dark_file_name="qubes-updater-dark.css",
+        )
+        qui.updater.utils.SetEffectiveCssProvider(self.EffectiveCssProvider)
 
         self.header_label: Gtk.Label = self.builder.get_object("header_label")
 
@@ -107,22 +112,25 @@ class QubesUpdater(Gtk.Application):
             self.header_label,
             self.next_button,
             self.cancel_button,
-            callback=lambda: self.next_clicked(None)
-                     if self.cliargs.non_interactive else lambda: None
+            callback=lambda: (
+                self.next_clicked(None)
+                if self.cliargs.non_interactive
+                else lambda: None
+            ),
         )
         self.summary_page = SummaryPage(
             self.builder,
             self.log,
             self.next_button,
             self.cancel_button,
-            self.progress_page.back_by_row_selection
+            self.progress_page.back_by_row_selection,
         )
 
-        self.button_settings: Gtk.Button = self.builder.get_object(
-            "button_settings")
+        self.button_settings: Gtk.Button = self.builder.get_object("button_settings")
         self.button_settings.connect("clicked", self.open_settings_window)
         settings_pixbuf = load_icon_at_gtk_size(
-            'qubes-customize', Gtk.IconSize.LARGE_TOOLBAR)
+            "qubes-customize", Gtk.IconSize.LARGE_TOOLBAR
+        )
         settings_image = Gtk.Image.new_from_pixbuf(settings_pixbuf)
         self.button_settings.set_image(settings_image)
 
@@ -152,9 +160,16 @@ class QubesUpdater(Gtk.Application):
             overrides=overrides,
         )
 
-        headers = [(3, "intro_name"), (3, "progress_name"), (3, "summary_name"),
-                   (3, "restart_name"), (4, "available"), (5, "check"),
-                   (6, "update"), (8, "summary_status")]
+        headers = [
+            (3, "intro_name"),
+            (3, "progress_name"),
+            (3, "summary_name"),
+            (3, "restart_name"),
+            (4, "available"),
+            (5, "check"),
+            (6, "update"),
+            (8, "summary_status"),
+        ]
 
         def cell_data_func(_column, cell, model, it, data):
             # Get the object from the model
@@ -163,10 +178,8 @@ class QubesUpdater(Gtk.Application):
             cell.set_property("markup", str(obj))
 
         for col, name in headers:
-            renderer: Gtk.CellRenderer = self.builder.get_object(
-                name + "_renderer")
-            column: Gtk.TreeViewColumn = self.builder.get_object(
-                name + "_column")
+            renderer: Gtk.CellRenderer = self.builder.get_object(name + "_renderer")
+            column: Gtk.TreeViewColumn = self.builder.get_object(name + "_column")
             column.set_cell_data_func(renderer, cell_data_func, col)
             renderer.props.ypad = 10
             if not name.endswith("name") and name != "summary_status":
@@ -181,7 +194,8 @@ class QubesUpdater(Gtk.Application):
         if skip_intro_if_args(self.cliargs):
             self.log.info("Skipping intro page.")
             self.intro_page.select_rows_ignoring_conditions(
-                cliargs=self.cliargs, dom0=self.qapp.domains['dom0'])
+                cliargs=self.cliargs, dom0=self.qapp.domains["dom0"]
+            )
             if len(self.intro_page.get_vms_to_update()) == 0:
                 self.do_nothing = True
                 return
@@ -189,12 +203,10 @@ class QubesUpdater(Gtk.Application):
         else:
             # default update_if_stale -> do nothing
             if self.cliargs.update_if_available:
-                self.intro_page.head_checkbox.state = (
-                    self.intro_page.head_checkbox.SAFE)
+                self.intro_page.head_checkbox.state = self.intro_page.head_checkbox.SAFE
                 self.intro_page.select_rows()
             elif self.cliargs.force_update:
-                self.intro_page.head_checkbox.state = (
-                    self.intro_page.head_checkbox.ALL)
+                self.intro_page.head_checkbox.state = self.intro_page.head_checkbox.ALL
                 self.intro_page.select_rows()
             self.log.info("Show intro page.")
         self.main_window.show_all()
@@ -226,10 +238,11 @@ class QubesUpdater(Gtk.Application):
                 self.summary_page.populate_restart_list(
                     restart=True,
                     vm_updated=self.progress_page.vms_to_update,
-                    settings=self.settings
+                    settings=self.settings,
                 )
             updated, no_updates, failed, cancelled = (
-                self.progress_page.get_update_summary())
+                self.progress_page.get_update_summary()
+            )
             if updated == 0:
                 # no updates
                 self.retcode = 100
@@ -244,8 +257,7 @@ class QubesUpdater(Gtk.Application):
                 self.summary_page.show(updated, no_updates, failed + cancelled)
             else:
                 # at this point retcode is in (0, 100)
-                self._restart_phase(
-                    show_only_error=self.cliargs.non_interactive)
+                self._restart_phase(show_only_error=self.cliargs.non_interactive)
                 # at thi point retcode is in (0, 100)
                 # or an error message have been already shown
                 if self.cliargs.non_interactive and self.retcode in (0, 100):
@@ -272,16 +284,16 @@ class QubesUpdater(Gtk.Application):
         we should show some feedback to the user.
         """
         non_default_select = any(
-            (getattr(self.cliargs, arg)
-             for arg in self.cliargs.non_default_select if arg != 'all'))
+            (
+                getattr(self.cliargs, arg)
+                for arg in self.cliargs.non_default_select
+                if arg != "all"
+            )
+        )
         msg = "Nothing to do."
-        if (
-                (  # at least all vms with available updates was updated
-                (self.cliargs.all and not self.cliargs.skip)
-                or not non_default_select
-                )
-                and self.retcode in (0, 100)
-        ):
+        if (  # at least all vms with available updates was updated
+            (self.cliargs.all and not self.cliargs.skip) or not non_default_select
+        ) and self.retcode in (0, 100):
             msg = "Qubes OS is up to date."
         elif self.retcode == 0:
             msg = "All selected qubes have been updated."
@@ -292,7 +304,7 @@ class QubesUpdater(Gtk.Application):
             l("Success"),
             l(msg),
             buttons=RESPONSES_OK,
-            icon_name="qubes-check-yes"
+            icon_name="qubes-check-yes",
         )
 
     def cancel_clicked(self, _emitter):
@@ -306,14 +318,22 @@ class QubesUpdater(Gtk.Application):
 
     def cancel_updates(self, *_args, **_kwargs):
         self.log.info("User initialize interruption")
-        if self.progress_page.update_thread \
-                and self.progress_page.update_thread.is_alive():
+        if (
+            self.progress_page.update_thread
+            and self.progress_page.update_thread.is_alive()
+        ):
             self.progress_page.interrupt_update()
             self.log.info("Update interrupted")
-            show_dialog_with_icon(self.main_window, l("Updating cancelled"), l(
-                "Waiting for current qube to finish updating."
-                " Updates for remaining qubes have been cancelled."),
-                                  buttons=RESPONSES_OK, icon_name="qubes-info")
+            show_dialog_with_icon(
+                self.main_window,
+                l("Updating cancelled"),
+                l(
+                    "Waiting for current qube to finish updating."
+                    " Updates for remaining qubes have been cancelled."
+                ),
+                buttons=RESPONSES_OK,
+                icon_name="qubes-info",
+            )
 
             self.log.debug("Waiting to finish ongoing updates")
             while self.progress_page.update_thread.is_alive():
@@ -343,30 +363,44 @@ class QubesUpdater(Gtk.Application):
 def parse_args(args, app):
     parser = argparse.ArgumentParser()
     try:
-        default_update_if_stale = int(app.domains["dom0"].features.get(
-            "qubes-vm-update-update-if-stale", Settings.DEFAULT_UPDATE_IF_STALE)
+        default_update_if_stale = int(
+            app.domains["dom0"].features.get(
+                "qubes-vm-update-update-if-stale",
+                Settings.DEFAULT_UPDATE_IF_STALE,
+            )
         )
     except qubesadmin.exc.QubesDaemonAccessError:
         default_update_if_stale = Settings.DEFAULT_UPDATE_IF_STALE
 
-    parser.add_argument('--log', action='store', default='WARNING',
-                        help='Provide logging level. Values: DEBUG, INFO, '
-                             'WARNING (default), ERROR, CRITICAL')
-
-    parser.add_argument('--max-concurrency', action='store',
-                        help='Maximum number of VMs configured simultaneously '
-                             '(default: number of cpus)',
-                        type=int)
     parser.add_argument(
-        '--signal-no-updates', action='store_true',
-        help='Return exit code 100 instread of 0 '
-             'if there is no updates available.')
+        "--log",
+        action="store",
+        default="WARNING",
+        help="Provide logging level. Values: DEBUG, INFO, "
+        "WARNING (default), ERROR, CRITICAL",
+    )
+
+    parser.add_argument(
+        "--max-concurrency",
+        action="store",
+        help="Maximum number of VMs configured simultaneously "
+        "(default: number of cpus)",
+        type=int,
+    )
+    parser.add_argument(
+        "--signal-no-updates",
+        action="store_true",
+        help="Return exit code 100 instread of 0 if there is no updates available.",
+    )
 
     restart = parser.add_mutually_exclusive_group()
     restart.add_argument(
-        '--apply-to-sys', '--restart', '-r',
-        action='store_true',
-        help='Restart not updated ServiceVMs whose template has been updated.')
+        "--apply-to-sys",
+        "--restart",
+        "-r",
+        action="store_true",
+        help="Restart service qubes with updated templates.",
+    )
     restart.add_argument(
         "--apply-to-all",
         "-R",
@@ -374,61 +408,93 @@ def parse_args(args, app):
         help="Restart service qubes and AppVMs with updated templates.",
     )
     restart.add_argument(
-        '--no-apply', action='store_true',
-        help='DEFAULT. Do not restart/shutdown any AppVMs.')
+        "--no-apply",
+        action="store_true",
+        help="DEFAULT. Do not restart/shutdown any AppVMs.",
+    )
 
     update_state = parser.add_mutually_exclusive_group()
     update_state.add_argument(
-        '--force-update', action='store_true',
-        help='Attempt to update all targeted VMs '
-             'even if no updates are available')
+        "--force-update",
+        action="store_true",
+        help="Attempt to update all targeted VMs even if no updates are available",
+    )
     update_state.add_argument(
-        '--update-if-stale', action='store',
-        help='DEFAULT. '
-             'Attempt to update targeted VMs with known updates available '
-             'or for which last update check was more than N days ago. '
-             '(default: %(default)d)',
-        type=int, default=default_update_if_stale)
+        "--update-if-stale",
+        action="store",
+        help="DEFAULT. "
+        "Attempt to update targeted VMs with known updates available "
+        "or for which last update check was more than N days ago. "
+        "(default: %(default)d)",
+        type=int,
+        default=default_update_if_stale,
+    )
     update_state.add_argument(
-        '--update-if-available', action='store_true',
-        help='Update targeted VMs with known updates available.')
+        "--update-if-available",
+        action="store_true",
+        help="Update targeted VMs with known updates available.",
+    )
 
     parser.add_argument(
-        '--skip', action='store',
-        help='Comma separated list of VMs to be skipped, '
-             'works with all other options. '
-             'If present, skip manual selection of qubes to update.',
-        default="")
+        "--skip",
+        action="store",
+        help="Comma separated list of VMs to be skipped, "
+        "works with all other options. "
+        "If present, skip manual selection of qubes to update.",
+        default="",
+    )
     parser.add_argument(
-        '--targets', action='store',
-        help='Comma separated list of updatable VMs to target. '
-             'If present, skip manual selection of qubes to update.')
+        "--targets",
+        action="store",
+        help="Comma separated list of updatable VMs to target. "
+        "If present, skip manual selection of qubes to update.",
+    )
     parser.add_argument(
-        '--templates', '-T', action='store_true',
-        help='Target all updatable TemplateVMs. '
-             'If present, skip manual selection of qubes to update.')
+        "--templates",
+        "-T",
+        action="store_true",
+        help="Target all updatable TemplateVMs. "
+        "If present, skip manual selection of qubes to update.",
+    )
     parser.add_argument(
-        '--standalones', '-S', action='store_true',
-        help='Target all updatable StandaloneVMs. '
-             'If present, skip manual selection of qubes to update.')
+        "--standalones",
+        "-S",
+        action="store_true",
+        help="Target all updatable StandaloneVMs. "
+        "If present, skip manual selection of qubes to update.",
+    )
     parser.add_argument(
-        '--all', action='store_true',
-        help='DEFAULT. Target AdminVM, TemplateVMs and StandaloneVMs.'
-             'Use explicitly with "--targets" to include both. '
-             'If explicitly present, skip manual selection of qubes to update.')
+        "--all",
+        action="store_true",
+        help="DEFAULT. Target AdminVM, TemplateVMs and StandaloneVMs."
+        'Use explicitly with "--targets" to include both. '
+        "If explicitly present, skip manual selection of qubes to update.",
+    )
     parser.add_argument(
-        '--dom0', action='store_true', help='Target dom0. '
-        'If present, skip manual selection of qubes to update.')
+        "--dom0",
+        action="store_true",
+        help="Target dom0. If present, skip manual selection of qubes to update.",
+    )
 
-    parser.add_argument('--non-interactive', '-n', action='store_true',
-                        help='Run the updater GUI in non-interactive mode. '
-                             'Interaction will be required in the event '
-                             'of an update error.')
+    parser.add_argument(
+        "--non-interactive",
+        "-n",
+        action="store_true",
+        help="Run the updater GUI in non-interactive mode. "
+        "Interaction will be required in the event "
+        "of an update error.",
+    )
 
     args = parser.parse_args(args)
 
     args.non_default_select = {
-        'skip', 'targets', 'templates', 'standalones', 'all', 'dom0'}
+        "skip",
+        "targets",
+        "templates",
+        "standalones",
+        "all",
+        "dom0",
+    }
 
     if args.update_if_stale < 0:
         raise ArgumentError("Wrong value for --update-if-stale")
@@ -439,8 +505,9 @@ def parse_args(args, app):
 
 
 def skip_intro_if_args(args):
-    auto_select = [getattr(args, arg) for arg in args.non_default_select
-                   ] + [args.non_interactive]
+    auto_select = [getattr(args, arg) for arg in args.non_default_select] + [
+        args.non_interactive
+    ]
     return any(auto_select)
 
 
@@ -454,5 +521,5 @@ def main(args=None):
     sys.exit(app.retcode)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
